@@ -25,13 +25,15 @@
 
 #include <gtk/gtk.h>
 
+#include <ags/libags.h>
+#include <ags/libags-audio.h>
 #include <ags/libags-gui.h>
 
 #include <ags/X/ags_machine.h>
 
 #include <ags/X/editor/ags_automation_toolbar.h>
 #include <ags/X/editor/ags_machine_selector.h>
-#include <ags/X/editor/ags_scale.h>
+#include <ags/X/editor/ags_scrolled_automation_edit_box.h>
 #include <ags/X/editor/ags_automation_edit.h>
 
 #define AGS_TYPE_AUTOMATION_EDITOR                (ags_automation_editor_get_type())
@@ -43,15 +45,22 @@
 
 #define AGS_AUTOMATION_EDITOR_CHILD(ptr) ((AgsAutomationEditorChild *)(ptr))
 
-#define AGS_AUTOMATION_EDITOR_DEFAULT_VERSION "0.7.29"
-#define AGS_AUTOMATION_EDITOR_DEFAULT_BUILD_ID "Mon Jun 13 11:50:58 UTC 2016"
+#define AGS_AUTOMATION_EDITOR_MAX_VALUE_COUNT (64 * 16 * 16 * 1200)
+#define AGS_AUTOMATION_EDITOR_MAX_CONTROLS (64 * 16 * 16 * 1200)
+
+#define AGS_AUTOMATION_EDITOR_DEFAULT_VERSION "1.3.0"
+#define AGS_AUTOMATION_EDITOR_DEFAULT_BUILD_ID "Wed Dec 27 03:43:55 UTC 2017"
 
 typedef struct _AgsAutomationEditor AgsAutomationEditor;
 typedef struct _AgsAutomationEditorClass AgsAutomationEditorClass;
-typedef struct _AgsAutomationEditorChild AgsAutomationEditorChild;
   
 typedef enum{
-  AGS_AUTOMATION_EDITOR_CONNECTED    = 1,
+  AGS_AUTOMATION_EDITOR_CONNECTED                 = 1,
+  AGS_AUTOMATION_EDITOR_RESET_AUDIO_HSCROLLBAR    = 1 <<  1,
+  AGS_AUTOMATION_EDITOR_RESET_OUTPUT_HSCROLLBAR   = 1 <<  2,
+  AGS_AUTOMATION_EDITOR_RESET_INPUT_HSCROLLBAR    = 1 <<  3,
+  AGS_AUTOMATION_EDITOR_PASTE_MATCH_LINE          = 1 <<  4,
+  AGS_AUTOMATION_EDITOR_PASTE_NO_DUPLICATES       = 1 <<  5,
 }AgsAutomationEditorFlags;
 
 struct _AgsAutomationEditor
@@ -63,7 +72,14 @@ struct _AgsAutomationEditor
   gchar *version;
   gchar *build_id;
 
+  guint tact_counter;
+  gdouble current_tact;
+
+  guint chunk_duration;
+
   GObject *soundcard;
+
+  GtkHPaned *paned;
   
   AgsMachineSelector *machine_selector;
   AgsMachine *selected_machine;
@@ -72,24 +88,27 @@ struct _AgsAutomationEditor
 
   GtkNotebook *notebook;
 
-  GList *automation_editor_child;
-  GtkTable *audio_table;
-  GtkTable *output_table;
-  GtkTable *input_table;
+  AgsRuler *audio_ruler;
+  AgsScrolledScaleBox *audio_scrolled_scale_box;
+  AgsScrolledAutomationEditBox *audio_scrolled_automation_edit_box;
+  GtkVScrollbar *audio_vscrollbar;
+  GtkHScrollbar *audio_hscrollbar;
   
-  AgsScale *current_audio_scale;
-  GtkWidget *current_audio_automation_edit;
+  AgsNotebook *output_notebook;
+  AgsRuler *output_ruler;
+  AgsScrolledScaleBox *output_scrolled_scale_box;
+  AgsScrolledAutomationEditBox *output_scrolled_automation_edit_box;
+  GtkVScrollbar *output_vscrollbar;
+  GtkHScrollbar *output_hscrollbar;
 
-  AgsNotebook *current_output_notebook;
-  AgsScale *current_output_scale;
-  GtkWidget *current_output_automation_edit;
+  AgsNotebook *input_notebook;
+  AgsRuler *input_ruler;
+  AgsScrolledScaleBox *input_scrolled_scale_box;
+  AgsScrolledAutomationEditBox *input_scrolled_automation_edit_box;
+  GtkVScrollbar *input_vscrollbar;
+  GtkHScrollbar *input_hscrollbar;
 
-  AgsNotebook *current_input_notebook;
-  AgsScale *current_input_scale;
-  GtkWidget *current_input_automation_edit;
-
-  guint tact_counter;
-  gdouble current_tact;
+  AgsAutomationEdit *focused_automation_edit;
 };
 
 struct _AgsAutomationEditorClass
@@ -100,37 +119,25 @@ struct _AgsAutomationEditorClass
 			  AgsMachine *machine);
 };
 
-struct _AgsAutomationEditorChild
-{
-  AgsMachine *machine;
-  
-  AgsScale *audio_scale;
-  AgsAutomationEdit *audio_automation_edit;
-
-  AgsScale *output_scale;
-  AgsNotebook *output_notebook;
-  AgsAutomationEdit *output_automation_edit;
-
-  AgsScale *input_scale;
-  AgsNotebook *input_notebook;
-  AgsAutomationEdit *input_automation_edit;
-};
-  
 GType ags_automation_editor_get_type(void);
 
-AgsAutomationEditorChild* ags_automation_editor_child_alloc(AgsMachine *machine,
-							    AgsScale *audio_scale, AgsAutomationEdit *audio_automation_edit,
-							    AgsNotebook *output_notebook, AgsScale *output_scale, AgsAutomationEdit *output_automation_edit,
-							    AgsNotebook *input_notebook, AgsScale *input_scale, AgsAutomationEdit *input_automation_edit);
-
-void ags_automation_editor_reset_port(AgsAutomationEditor *automation_editor,
-				      AgsMachine *machine,
-				      GType channel_type,
-				      gchar **remove_specifier);
+void ags_automation_editor_reset_audio_scrollbar(AgsAutomationEditor *automation_editor);
+void ags_automation_editor_reset_output_scrollbar(AgsAutomationEditor *automation_editor);
+void ags_automation_editor_reset_input_scrollbar(AgsAutomationEditor *automation_editor);
 
 void ags_automation_editor_machine_changed(AgsAutomationEditor *automation_editor,
 					   AgsMachine *machine);
 
+void ags_automation_editor_add_acceleration(AgsAutomationEditor *automation_editor,
+					    AgsAcceleration *acceleration);
+
+void ags_automation_editor_delete_acceleration(AgsAutomationEditor *automation_editor,
+					       guint x, gdouble y);
+
+void ags_automation_editor_select_region(AgsAutomationEditor *automation_editor,
+					 guint x0, gdouble y0,
+					 guint x1, gdouble y1);
+
 void ags_automation_editor_select_all(AgsAutomationEditor *automation_editor);
 
 void ags_automation_editor_paste(AgsAutomationEditor *automation_editor);
