@@ -799,17 +799,22 @@ ags_effect_bridge_real_resize_pads(AgsEffectBridge *effect_bridge,
 
     /* connect and show */
     if((AGS_EFFECT_BRIDGE_CONNECTED & (effect_bridge->flags)) != 0){
+      GtkContainer *container;
       GList *list;
+
+      container = (GtkContainer *) ((channel_type == AGS_TYPE_OUTPUT) ? effect_bridge->output: effect_bridge->input);
+
+      if(container != NULL){
+	list = gtk_container_get_children(container);
+	list = g_list_nth(list,
+			  old_size);
       
-      list = gtk_container_get_children((GtkContainer *) ((channel_type == AGS_TYPE_OUTPUT) ? effect_bridge->output: effect_bridge->input));
-      list = g_list_nth(list,
-			old_size);
-      
-      while(list != NULL){
-	ags_connectable_connect(AGS_CONNECTABLE(list->data));
-	gtk_widget_show_all(list->data);
+	while(list != NULL){
+	  ags_connectable_connect(AGS_CONNECTABLE(list->data));
+	  gtk_widget_show_all(list->data);
 	
-	list = list->next;
+	  list = list->next;
+	}
       }
     }
   }else{
