@@ -1496,10 +1496,7 @@ ags_effect_line_real_remove_effect(AgsEffectLine *effect_line,
 			    nth_effect);
 
   /* reset automation editor */
-  ags_automation_editor_reset_port(window->automation_window->automation_editor,
-				   machine,
-				   (AGS_IS_OUTPUT(effect_line->channel) ? AGS_TYPE_OUTPUT: AGS_TYPE_INPUT),
-				   remove_specifier);
+  ags_automation_toolbar_load_port(window->automation_window->automation_editor->automation_toolbar);
 }
 
 /**
