@@ -27,20 +27,41 @@
 int
 ags_line_editor_parent_set_callback(GtkWidget *widget, GtkObject *old_parent, AgsLineEditor *line_editor)
 {
-  if(old_parent != NULL)
+  if(old_parent != NULL){
     return(0);
+  }
 
-  gtk_box_pack_start((GtkBox *) line_editor,
-		     (GtkWidget *) line_editor->link_editor,
-		     FALSE, FALSE, 0);
+  if(line_editor->link_editor != NULL){
+    gtk_box_pack_start((GtkBox *) line_editor,
+		       (GtkWidget *) line_editor->link_editor,
+		       FALSE, FALSE,
+		       0);
+  }
+
+  if(line_editor->output_editor != NULL){
+    gtk_box_pack_start((GtkBox *) line_editor,
+		       (GtkWidget *) line_editor->output_editor,
+		       FALSE, FALSE,
+		       0);
+  }
+    
   return(0);
 }
 
 int
 ags_line_editor_show_callback(GtkWidget *widget, AgsLineEditor *line_editor)
 {
-  gtk_widget_show((GtkWidget *) line_editor->link_editor);
-  gtk_widget_show((GtkWidget *) line_editor->member_editor);
+  if(line_editor->link_editor != NULL){
+    gtk_widget_show((GtkWidget *) line_editor->link_editor);
+  }
+  
+  if(line_editor->output_editor != NULL){
+    gtk_widget_show((GtkWidget *) line_editor->output_editor);
+  }
 
+  if(line_editor->member_editor != NULL){
+    gtk_widget_show((GtkWidget *) line_editor->member_editor);
+  }
+  
   return(0);
 }
