@@ -41,6 +41,10 @@ struct _AgsLv2Browser
   gchar *path;
 
   GtkHBox *plugin;
+
+  GtkComboBox *filename;
+  GtkComboBox *effect;
+
   GtkVBox *description;
 
   GtkWidget *preview;
@@ -56,8 +60,12 @@ GType ags_lv2_browser_get_type(void);
 gchar* ags_lv2_browser_get_plugin_filename(AgsLv2Browser *lv2_browser);
 gchar* ags_lv2_browser_get_plugin_effect(AgsLv2Browser *lv2_browser);
 
+GtkWidget* ags_lv2_browser_combo_box_output_boolean_controls_new();
+GtkWidget* ags_lv2_browser_combo_box_output_controls_new();
+
 GtkWidget* ags_lv2_browser_combo_box_boolean_controls_new();
 GtkWidget* ags_lv2_browser_combo_box_controls_new();
+
 GtkWidget* ags_lv2_browser_preview_new();
 
 AgsLv2Browser* ags_lv2_browser_new();
