@@ -55,9 +55,11 @@ ags_lv2_browser_plugin_filename_callback(GtkComboBoxText *combo_box,
   list = lv2_manager->lv2_plugin;
 
   while((list = ags_base_plugin_find_filename(list, gtk_combo_box_text_get_active_text(filename))) != NULL){
-    gtk_combo_box_text_append_text(effect,
-				   g_strdup_printf("%s", AGS_BASE_PLUGIN(list->data)->effect));
-
+    if(AGS_BASE_PLUGIN(list->data)->effect != NULL){
+      gtk_combo_box_text_append_text(effect,
+				     AGS_BASE_PLUGIN(list->data)->effect);
+    }
+    
     list = list->next;
   }
   
@@ -133,11 +135,14 @@ ags_lv2_browser_plugin_uri_callback(GtkComboBoxText *combo_box,
 
     list = list->next;
     label = GTK_LABEL(list->data);
+
+    str = g_strdup_printf("%s: ",
+			  i18n("Ports"));
     gtk_label_set_text(label,
-		       i18n("Ports: "));
+		       str);
 
     g_free(str);
-
+    
     list = list->next;
     table = GTK_TABLE(list->data);
 
