@@ -19,29 +19,10 @@
 
 #include <ags/X/ags_menu_action_callbacks.h>
 
-#include <ags/object/ags_application_context.h>
-#include <ags/object/ags_connectable.h>
-#include <ags/object/ags_applicable.h>
-#include <ags/object/ags_soundcard.h>
-#include <ags/object/ags_sequencer.h>
+#include <ags/libags.h>
+#include <ags/libags-audio.h>
 
-#include <ags/file/ags_file.h>
-
-#include <ags/thread/ags_mutex_manager.h>
-
-#include <ags/plugin/ags_lv2_manager.h>
-#include <ags/plugin/ags_lv2_plugin.h>
-
-#include <ags/audio/ags_midiin.h>
-#include <ags/audio/ags_input.h>
-#include <ags/audio/ags_output.h>
-
-#include <ags/audio/thread/ags_audio_loop.h>
-
-#include <ags/audio/task/ags_save_file.h>
-#include <ags/audio/task/ags_add_audio.h>
-
-#include <ags/X/ags_xorg_application_context.h>
+#include <ags/X/ags_ui_provider.h>
 #include <ags/X/ags_window.h>
 #include <ags/X/ags_export_window.h>
 
@@ -60,6 +41,7 @@
 #include <ags/X/machine/ags_synth.h>
 #include <ags/X/machine/ags_syncsynth.h>
 #include <ags/X/machine/ags_ffplayer.h>
+#include <ags/X/machine/ags_audiorec.h>
 #include <ags/X/machine/ags_ladspa_bridge.h>
 #include <ags/X/machine/ags_dssi_bridge.h>
 #include <ags/X/machine/ags_lv2_bridge.h>
@@ -78,13 +60,13 @@ void ags_menu_action_open_response_callback(GtkFileChooserDialog *file_chooser,
 void
 ags_menu_action_open_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   GtkFileChooserDialog *file_chooser;
   gint response;
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   file_chooser = (GtkFileChooserDialog *) gtk_file_chooser_dialog_new("open file",
 								      (GtkWindow *) window,
@@ -130,13 +112,13 @@ ags_menu_action_open_response_callback(GtkFileChooserDialog *file_chooser, gint
 void
 ags_menu_action_save_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   
   GError *error;
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   if(g_strcmp0(ags_config_get_value(AGS_APPLICATION_CONTEXT(application_context)->config,
 				    AGS_CONFIG_GENERIC,
@@ -177,14 +159,14 @@ ags_menu_action_save_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_save_as_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   GtkFileChooserDialog *file_chooser;
   
   gint response;
         
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   file_chooser = (GtkFileChooserDialog *) gtk_file_chooser_dialog_new("save file as",
 								      (GtkWindow *) window,
@@ -259,11 +241,11 @@ ags_menu_action_save_as_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_export_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   gtk_widget_show_all((GtkWidget *) window->export_window);
 }
@@ -271,14 +253,14 @@ ags_menu_action_export_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_quit_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   GtkDialog *dialog;
   GtkWidget *cancel_button;
   gint response;
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   /* ask the user if he wants save to a file */
   dialog = (GtkDialog *) gtk_message_dialog_new(GTK_WINDOW(window),
@@ -322,7 +304,7 @@ ags_menu_action_add_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_panel_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsPanel *panel;
   
@@ -335,7 +317,7 @@ ags_menu_action_add_panel_callback(GtkWidget *menu_item, gpointer data)
   pthread_mutex_t *application_mutex;
     
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   mutex_manager = ags_mutex_manager_get_instance();
   application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);
@@ -360,7 +342,8 @@ ags_menu_action_add_panel_callback(GtkWidget *menu_item, gpointer data)
 
   gtk_box_pack_start((GtkBox *) window->machines,
 		     GTK_WIDGET(panel),
-		     FALSE, FALSE, 0);
+		     FALSE, FALSE,
+		     0);
 
   AGS_MACHINE(panel)->audio->audio_channels = 2;
 
@@ -377,7 +360,7 @@ ags_menu_action_add_panel_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_mixer_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsMixer *mixer;
 
@@ -390,7 +373,7 @@ ags_menu_action_add_mixer_callback(GtkWidget *menu_item, gpointer data)
   pthread_mutex_t *application_mutex;
     
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   mutex_manager = ags_mutex_manager_get_instance();
   application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);
@@ -415,7 +398,8 @@ ags_menu_action_add_mixer_callback(GtkWidget *menu_item, gpointer data)
 
   gtk_box_pack_start((GtkBox *) window->machines,
 		     GTK_WIDGET(mixer),
-		     FALSE, FALSE, 0);
+		     FALSE, FALSE,
+		     0);
 
   ags_connectable_connect(AGS_CONNECTABLE(mixer));
 
@@ -431,7 +415,7 @@ ags_menu_action_add_mixer_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_drum_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsDrum *drum;
 
@@ -444,7 +428,7 @@ ags_menu_action_add_drum_callback(GtkWidget *menu_item, gpointer data)
   pthread_mutex_t *application_mutex;
     
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   drum = ags_drum_new(G_OBJECT(window->soundcard));
 
@@ -469,7 +453,8 @@ ags_menu_action_add_drum_callback(GtkWidget *menu_item, gpointer data)
 
   gtk_box_pack_start((GtkBox *) window->machines,
 		     GTK_WIDGET(drum),
-		     FALSE, FALSE, 0);
+		     FALSE, FALSE,
+		     0);
 
   /* connect everything */
   ags_connectable_connect(AGS_CONNECTABLE(drum));
@@ -488,7 +473,7 @@ ags_menu_action_add_drum_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_matrix_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsMatrix *matrix;
 
@@ -501,7 +486,7 @@ ags_menu_action_add_matrix_callback(GtkWidget *menu_item, gpointer data)
   pthread_mutex_t *application_mutex;
   
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
   
   matrix = ags_matrix_new(G_OBJECT(window->soundcard));
 
@@ -526,7 +511,8 @@ ags_menu_action_add_matrix_callback(GtkWidget *menu_item, gpointer data)
   
   gtk_box_pack_start((GtkBox *) window->machines,
 		     GTK_WIDGET(matrix),
-		     FALSE, FALSE, 0);
+		     FALSE, FALSE,
+		     0);
   
   /* connect everything */
   ags_connectable_connect(AGS_CONNECTABLE(matrix));
@@ -545,7 +531,7 @@ ags_menu_action_add_matrix_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_synth_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsSynth *synth;
 
@@ -558,7 +544,7 @@ ags_menu_action_add_synth_callback(GtkWidget *menu_item, gpointer data)
   pthread_mutex_t *application_mutex;
     
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   synth = ags_synth_new(G_OBJECT(window->soundcard));
 
@@ -583,7 +569,8 @@ ags_menu_action_add_synth_callback(GtkWidget *menu_item, gpointer data)
 
   gtk_box_pack_start((GtkBox *) window->machines,
 		     (GtkWidget *) synth,
-		     FALSE, FALSE, 0);
+		     FALSE, FALSE,
+		     0);
 
   ags_connectable_connect(AGS_CONNECTABLE(synth));
 
@@ -597,7 +584,7 @@ ags_menu_action_add_synth_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_syncsynth_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsSyncsynth *syncsynth;
 
@@ -610,7 +597,7 @@ ags_menu_action_add_syncsynth_callback(GtkWidget *menu_item, gpointer data)
   pthread_mutex_t *application_mutex;
   
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   syncsynth = ags_syncsynth_new(G_OBJECT(window->soundcard));
 
@@ -635,7 +622,8 @@ ags_menu_action_add_syncsynth_callback(GtkWidget *menu_item, gpointer data)
 
   gtk_box_pack_start((GtkBox *) window->machines,
 		     (GtkWidget *) syncsynth,
-		     FALSE, FALSE, 0);
+		     FALSE, FALSE,
+		     0);
 
   ags_connectable_connect(AGS_CONNECTABLE(syncsynth));
 
@@ -649,7 +637,7 @@ ags_menu_action_add_syncsynth_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_ffplayer_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsFFPlayer *ffplayer;
 
@@ -662,7 +650,7 @@ ags_menu_action_add_ffplayer_callback(GtkWidget *menu_item, gpointer data)
   pthread_mutex_t *application_mutex;
   
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   ffplayer = ags_ffplayer_new(G_OBJECT(window->soundcard));
 
@@ -687,7 +675,8 @@ ags_menu_action_add_ffplayer_callback(GtkWidget *menu_item, gpointer data)
 
   gtk_box_pack_start((GtkBox *) window->machines,
 		     (GtkWidget *) ffplayer,
-		     FALSE, FALSE, 0);
+		     FALSE, FALSE,
+		     0);
 
   ags_connectable_connect(AGS_CONNECTABLE(ffplayer));
 
@@ -699,10 +688,64 @@ ags_menu_action_add_ffplayer_callback(GtkWidget *menu_item, gpointer data)
   gtk_widget_show_all((GtkWidget *) ffplayer);
 }
 
+void
+ags_menu_action_add_audiorec_callback(GtkWidget *menu_item, gpointer data)
+{
+  AgsApplicationContext *application_context;
+  AgsWindow *window;
+  AgsAudiorec *audiorec;
+
+  AgsAddAudio *add_audio;
+
+  AgsMutexManager *mutex_manager;
+  AgsThread *main_loop;
+  AgsGuiThread *gui_thread;
+
+  pthread_mutex_t *application_mutex;
+  
+  application_context = ags_application_context_get_instance();
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
+
+  audiorec = ags_audiorec_new(G_OBJECT(window->soundcard));
+
+  mutex_manager = ags_mutex_manager_get_instance();
+  application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);    
+
+  /* get audio loop */
+  pthread_mutex_lock(application_mutex);
+
+  main_loop = (AgsThread *) AGS_APPLICATION_CONTEXT(application_context)->main_loop;
+
+  pthread_mutex_unlock(application_mutex);
+
+  /* get task thread */
+  gui_thread = (AgsGuiThread *) ags_thread_find_type(main_loop,
+						     AGS_TYPE_GUI_THREAD);
+
+  add_audio = ags_add_audio_new(window->soundcard,
+				AGS_MACHINE(audiorec)->audio);
+  ags_gui_thread_schedule_task(gui_thread,
+			       add_audio);
+
+  gtk_box_pack_start((GtkBox *) window->machines,
+		     (GtkWidget *) audiorec,
+		     FALSE, FALSE,
+		     0);
+
+  ags_connectable_connect(AGS_CONNECTABLE(audiorec));
+
+  //  audiorec->machine.audio->frequence = ;
+  audiorec->machine.audio->audio_channels = 2;
+  ags_audio_set_pads(AGS_MACHINE(audiorec)->audio, AGS_TYPE_INPUT, 1);
+  ags_audio_set_pads(AGS_MACHINE(audiorec)->audio, AGS_TYPE_OUTPUT, 1);  
+
+  gtk_widget_show_all((GtkWidget *) audiorec);
+}
+
 void
 ags_menu_action_add_ladspa_bridge_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsLadspaBridge *ladspa_bridge;
 
@@ -722,7 +765,7 @@ ags_menu_action_add_ladspa_bridge_callback(GtkWidget *menu_item, gpointer data)
 			     AGS_MENU_ITEM_EFFECT_KEY);
   
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
   ladspa_bridge = ags_ladspa_bridge_new(G_OBJECT(window->soundcard),
 					filename,
 					effect);
@@ -770,7 +813,7 @@ ags_menu_action_add_ladspa_bridge_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_dssi_bridge_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsDssiBridge *dssi_bridge;
 
@@ -790,7 +833,7 @@ ags_menu_action_add_dssi_bridge_callback(GtkWidget *menu_item, gpointer data)
 			     AGS_MENU_ITEM_EFFECT_KEY);
   
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
   dssi_bridge = ags_dssi_bridge_new(G_OBJECT(window->soundcard),
 				    filename,
 				    effect);
@@ -838,7 +881,7 @@ ags_menu_action_add_dssi_bridge_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_lv2_bridge_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsLv2Bridge *lv2_bridge;
 
@@ -860,7 +903,7 @@ ags_menu_action_add_lv2_bridge_callback(GtkWidget *menu_item, gpointer data)
 			     AGS_MENU_ITEM_EFFECT_KEY);
   
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
   lv2_bridge = ags_lv2_bridge_new(G_OBJECT(window->soundcard),
 				  filename,
 				  effect);
@@ -944,7 +987,7 @@ ags_menu_action_add_lv2_bridge_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_add_live_dssi_bridge_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsLiveDssiBridge *live_dssi_bridge;
 
@@ -964,7 +1007,7 @@ ags_menu_action_add_live_dssi_bridge_callback(GtkWidget *menu_item, gpointer dat
 			     AGS_MENU_ITEM_EFFECT_KEY);
   
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
   live_dssi_bridge = ags_live_dssi_bridge_new(G_OBJECT(window->soundcard),
 					      filename,
 					      effect);
@@ -1012,7 +1055,7 @@ ags_menu_action_add_live_dssi_bridge_callback(GtkWidget *menu_item, gpointer dat
 void
 ags_menu_action_add_live_lv2_bridge_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
   AgsLiveLv2Bridge *live_lv2_bridge;
 
@@ -1034,7 +1077,7 @@ ags_menu_action_add_live_lv2_bridge_callback(GtkWidget *menu_item, gpointer data
 			     AGS_MENU_ITEM_EFFECT_KEY);
   
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
   live_lv2_bridge = ags_live_lv2_bridge_new(G_OBJECT(window->soundcard),
 					    filename,
 					    effect);
@@ -1092,23 +1135,35 @@ ags_menu_action_add_live_lv2_bridge_callback(GtkWidget *menu_item, gpointer data
 void
 ags_menu_action_automation_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   gtk_widget_show_all((GtkWidget *) window->automation_window);
 }
 
 void
-ags_menu_action_preferences_callback(GtkWidget *menu_item, gpointer data)
+ags_menu_action_wave_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
+
+  gtk_widget_show_all((GtkWidget *) window->wave_window);
+}
+
+void
+ags_menu_action_preferences_callback(GtkWidget *menu_item, gpointer data)
+{
+  AgsApplicationContext *application_context;
+  AgsWindow *window;
+
+  application_context = ags_application_context_get_instance();
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   if(window->preferences != NULL){
     return;
@@ -1126,11 +1181,11 @@ ags_menu_action_preferences_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_midi_import_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   if(window->midi_import_wizard != NULL){
     return;
@@ -1151,11 +1206,11 @@ ags_menu_action_midi_import_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_midi_export_track_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   if(window->midi_export_wizard != NULL){
     return;
@@ -1182,7 +1237,7 @@ ags_menu_action_midi_playback_callback(GtkWidget *menu_item, gpointer data)
 void
 ags_menu_action_about_callback(GtkWidget *menu_item, gpointer data)
 {
-  AgsXorgApplicationContext *application_context;
+  AgsApplicationContext *application_context;
   AgsWindow *window;
 
   static FILE *file = NULL;
@@ -1244,7 +1299,7 @@ ags_menu_action_about_callback(GtkWidget *menu_item, gpointer data)
   }
 
   application_context = ags_application_context_get_instance();
-  window = application_context->window;
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
 
   gtk_show_about_dialog((GtkWindow *) window,
 			"program-name", "gsequencer",
