@@ -40,6 +40,7 @@ void ags_menu_action_add_matrix_callback(GtkWidget *menu_item, gpointer data);
 void ags_menu_action_add_synth_callback(GtkWidget *menu_item, gpointer data);
 void ags_menu_action_add_syncsynth_callback(GtkWidget *menu_item, gpointer data);
 void ags_menu_action_add_ffplayer_callback(GtkWidget *menu_item, gpointer data);
+void ags_menu_action_add_audiorec_callback(GtkWidget *menu_item, gpointer data);
 
 void ags_menu_action_add_ladspa_bridge_callback(GtkWidget *menu_item, gpointer data);
 void ags_menu_action_add_dssi_bridge_callback(GtkWidget *menu_item, gpointer data);
@@ -49,6 +50,7 @@ void ags_menu_action_add_live_dssi_bridge_callback(GtkWidget *menu_item, gpointe
 void ags_menu_action_add_live_lv2_bridge_callback(GtkWidget *menu_item, gpointer data);
 
 void ags_menu_action_automation_callback(GtkWidget *menu_item, gpointer data);
+void ags_menu_action_wave_callback(GtkWidget *menu_item, gpointer data);
 void ags_menu_action_preferences_callback(GtkWidget *menu_item, gpointer data);
 
 void ags_menu_action_midi_import_callback(GtkWidget *menu_item, gpointer data);
