@@ -20,19 +20,8 @@
 #include <ags/X/ags_output_collection_editor.h>
 #include <ags/X/ags_output_collection_editor_callbacks.h>
 
-#include <ags/object/ags_application_context.h>
-#include <ags/object/ags_connectable.h>
-#include <ags/object/ags_soundcard.h>
-#include <ags/object/ags_applicable.h>
-
-#include <ags/thread/ags_mutex_manager.h>
-
-#include <ags/audio/ags_audio.h>
-#include <ags/audio/ags_input.h>
-
-#include <ags/audio/thread/ags_audio_loop.h>
-
-#include <ags/audio/task/ags_reset_audio_connection.h>
+#include <ags/libags.h>
+#include <ags/libags-audio.h>
 
 #include <ags/X/ags_window.h>
 #include <ags/X/ags_machine.h>
@@ -351,7 +340,7 @@ ags_output_collection_editor_disconnect(AgsConnectable *connectable)
   output_collection_editor = AGS_OUTPUT_COLLECTION_EDITOR(connectable);
 
   g_object_disconnect(G_OBJECT(output_collection_editor->soundcard),
-		      "changed",
+		      "any_signal::changed",
 		      G_CALLBACK(ags_output_collection_editor_soundcard_callback),
 		      output_collection_editor,
 		      NULL);
