@@ -22,18 +22,19 @@
 
 #include <glib.h>
 #include <glib-object.h>
+
 #include <gtk/gtk.h>
 
-#include <ags/audio/ags_audio.h>
-
 #include <ags/X/ags_output_listing_editor.h>
 
+#include <ags/X/ags_machine.h>
+
 int ags_output_listing_editor_parent_set_callback(GtkWidget *widget,
 						  GtkObject *old_parent,
 						  AgsOutputListingEditor *output_listing_editor);
 
-void ags_output_listing_editor_set_pads_callback(AgsAudio *audio, GType channel_type,
-						 guint pads, guint pads_old,
-						 AgsOutputListingEditor *output_listing_editor);
+void ags_output_listing_editor_resize_pads_callback(AgsMachine *machine, GType channel_type,
+						    guint pads, guint pads_old,
+						    AgsOutputListingEditor *output_listing_editor);
 
 #endif /*__AGS_OUTPUT_LISTING_EDITOR_CALLBACKS_H__*/
