@@ -40,6 +40,9 @@ void
 ags_plugin_browser_ok_callback(GtkWidget *button,
 			       AgsPluginBrowser *plugin_browser)
 {
+  gtk_combo_box_set_active(plugin_browser->plugin_type,
+			   -1);
+  
   gtk_widget_hide((GtkWidget *) plugin_browser);
 }
 
@@ -47,6 +50,9 @@ void
 ags_plugin_browser_cancel_callback(GtkWidget *button,
 				   AgsPluginBrowser *plugin_browser)
 {
+  gtk_combo_box_set_active(plugin_browser->plugin_type,
+			   -1);
+
   gtk_widget_hide((GtkWidget *) plugin_browser);
 }
 
