@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2015 Joël Krähemann
+ * Copyright (C) 2005-2017 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -32,9 +32,9 @@ void ags_sequencer_editor_backend_changed_callback(GtkComboBox *combo,
 
 void ags_sequencer_editor_card_changed_callback(GtkComboBox *combo,
 						AgsSequencerEditor *sequencer_editor);
-void ags_sequencer_editor_add_jack_callback(GtkWidget *button,
-					    AgsSequencerEditor *sequencer_editor);
-void ags_sequencer_editor_remove_jack_callback(GtkWidget *button,
-					       AgsSequencerEditor *sequencer_editor);
+void ags_sequencer_editor_add_source_callback(GtkWidget *button,
+					      AgsSequencerEditor *sequencer_editor);
+void ags_sequencer_editor_remove_source_callback(GtkWidget *button,
+						 AgsSequencerEditor *sequencer_editor);
 
 #endif /*__AGS_SEQUENCER_EDITOR_CALLBACKS_H__*/
