@@ -32,8 +32,8 @@
 #define AGS_IS_AUTOMATION_TOOLBAR_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE ((class), AGS_TYPE_AUTOMATION_TOOLBAR))
 #define AGS_AUTOMATION_TOOLBAR_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS (obj, AGS_TYPE_AUTOMATION_TOOLBAR, AgsAutomationToolbarClass))
 
-#define AGS_AUTOMATION_TOOLBAR_DATA_CHANNEL "ags-channel\0"
-#define AGS_AUTOMATION_TOOLBAR_DATA_PORT "ags-port\0"
+#define AGS_AUTOMATION_TOOLBAR_DATA_CHANNEL "ags-channel"
+#define AGS_AUTOMATION_TOOLBAR_DATA_PORT "ags-port"
 
 typedef struct _AgsAutomationToolbar AgsAutomationToolbar;
 typedef struct _AgsAutomationToolbarClass AgsAutomationToolbarClass;
@@ -49,15 +49,15 @@ struct _AgsAutomationToolbar
 
   guint flags;
   
-  GtkToggleButton *selected_edit_mode;
-  GtkToggleButton *position;
-  GtkToggleButton *edit;
-  GtkToggleButton *clear;
-  GtkToggleButton *select;
+  GtkToggleToolButton *selected_edit_mode;
+  GtkToggleToolButton *position;
+  GtkToggleToolButton *edit;
+  GtkToggleToolButton *clear;
+  GtkToggleToolButton *select;
 
-  GtkButton *copy;
-  GtkButton *cut;
-  GtkButton *paste;
+  GtkToolButton *copy;
+  GtkToolButton *cut;
+  GtkMenuToolButton *paste_tool;
 
   GtkMenuToolButton *menu_tool;
   GtkMenu *tool_popup;
@@ -81,7 +81,7 @@ GType ags_automation_toolbar_get_type(void);
 
 void ags_automation_toolbar_load_port(AgsAutomationToolbar *automation_toolbar);
 void ags_automation_toolbar_apply_port(AgsAutomationToolbar *automation_toolbar,
-				       gchar *control_name);
+				       GType channel_type, gchar *control_name);
 
 GtkMenu* ags_automation_toolbar_tool_popup_new(GtkToolbar *automation_toolbar);
 
