@@ -43,35 +43,31 @@ ags_automation_toolbar_position_callback(GtkToggleButton *toggle_button, AgsAuto
 								      AGS_TYPE_AUTOMATION_EDITOR);
   
   if(toggle_button == automation_toolbar->selected_edit_mode){
-    if(!gtk_toggle_button_get_active(toggle_button)){
-      gtk_toggle_button_set_active(toggle_button, TRUE);
+    if(!gtk_toggle_tool_button_get_active(toggle_button)){
+      gtk_toggle_tool_button_set_active(toggle_button, TRUE);
     }
-  }else if(gtk_toggle_button_get_active(toggle_button)){
+  }else if(gtk_toggle_tool_button_get_active(toggle_button)){
     GtkToggleButton *old_selected_edit_mode;
     
     old_selected_edit_mode = automation_toolbar->selected_edit_mode;
     automation_toolbar->selected_edit_mode = toggle_button;
-    gtk_toggle_button_set_active(old_selected_edit_mode, FALSE);
+    gtk_toggle_tool_button_set_active(old_selected_edit_mode, FALSE);
   }
-
-  gtk_widget_queue_draw((GtkWidget *) automation_editor->current_audio_automation_edit);
-  gtk_widget_queue_draw((GtkWidget *) automation_editor->current_output_automation_edit);
-  gtk_widget_queue_draw((GtkWidget *) automation_editor->current_input_automation_edit);
 }
 
 void
 ags_automation_toolbar_edit_callback(GtkToggleButton *toggle_button, AgsAutomationToolbar *automation_toolbar)
 {
   if(toggle_button == automation_toolbar->selected_edit_mode){
-    if(!gtk_toggle_button_get_active(toggle_button)){
-      gtk_toggle_button_set_active(toggle_button, TRUE);
+    if(!gtk_toggle_tool_button_get_active(toggle_button)){
+      gtk_toggle_tool_button_set_active(toggle_button, TRUE);
     }
-  }else if(gtk_toggle_button_get_active(toggle_button)){
+  }else if(gtk_toggle_tool_button_get_active(toggle_button)){
     GtkToggleButton *old_selected_edit_mode;
     
     old_selected_edit_mode = automation_toolbar->selected_edit_mode;
     automation_toolbar->selected_edit_mode = toggle_button;
-    gtk_toggle_button_set_active(old_selected_edit_mode, FALSE);
+    gtk_toggle_tool_button_set_active(old_selected_edit_mode, FALSE);
   }
 }
 
@@ -79,15 +75,15 @@ void
 ags_automation_toolbar_clear_callback(GtkToggleButton *toggle_button, AgsAutomationToolbar *automation_toolbar)
 {
   if(toggle_button == automation_toolbar->selected_edit_mode){
-    if(!gtk_toggle_button_get_active(toggle_button)){
-      gtk_toggle_button_set_active(toggle_button, TRUE);
+    if(!gtk_toggle_tool_button_get_active(toggle_button)){
+      gtk_toggle_tool_button_set_active(toggle_button, TRUE);
     }
-  }else if(gtk_toggle_button_get_active(toggle_button)){
+  }else if(gtk_toggle_tool_button_get_active(toggle_button)){
     GtkToggleButton *old_selected_edit_mode;
     
     old_selected_edit_mode = automation_toolbar->selected_edit_mode;
     automation_toolbar->selected_edit_mode = toggle_button;
-    gtk_toggle_button_set_active(old_selected_edit_mode, FALSE);
+    gtk_toggle_tool_button_set_active(old_selected_edit_mode, FALSE);
   }
 }
 
@@ -95,15 +91,15 @@ void
 ags_automation_toolbar_select_callback(GtkToggleButton *toggle_button, AgsAutomationToolbar *automation_toolbar)
 {
   if(toggle_button == automation_toolbar->selected_edit_mode){
-    if(!gtk_toggle_button_get_active(toggle_button)){
-      gtk_toggle_button_set_active(toggle_button, TRUE);
+    if(!gtk_toggle_tool_button_get_active(toggle_button)){
+      gtk_toggle_tool_button_set_active(toggle_button, TRUE);
     }
-  }else if(gtk_toggle_button_get_active(toggle_button)){
+  }else if(gtk_toggle_tool_button_get_active(toggle_button)){
     GtkToggleButton *old_selected_edit_mode;
     
     old_selected_edit_mode = automation_toolbar->selected_edit_mode;
     automation_toolbar->selected_edit_mode = toggle_button;
-    gtk_toggle_button_set_active(old_selected_edit_mode, FALSE);
+    gtk_toggle_tool_button_set_active(old_selected_edit_mode, FALSE);
   }
 }
 
@@ -133,6 +129,36 @@ ags_automation_toolbar_paste_callback(GtkWidget *widget, AgsAutomationToolbar *a
   ags_automation_editor_paste(automation_editor);
 }
 
+void
+ags_automation_toolbar_match_line_callback(GtkWidget *widget, AgsAutomationToolbar *automation_toolbar)
+{
+  AgsAutomationEditor *automation_editor;
+
+  automation_editor = AGS_AUTOMATION_EDITOR(gtk_widget_get_ancestor(GTK_WIDGET(automation_toolbar),
+								    AGS_TYPE_AUTOMATION_EDITOR));
+
+  if(gtk_check_menu_item_get_active(widget)){
+    automation_editor->flags |= AGS_AUTOMATION_EDITOR_PASTE_MATCH_LINE;
+  }else{
+    automation_editor->flags &= (~AGS_AUTOMATION_EDITOR_PASTE_MATCH_LINE);
+  }
+}
+
+void
+ags_automation_toolbar_no_duplicates_callback(GtkWidget *widget, AgsAutomationToolbar *automation_toolbar)
+{
+  AgsAutomationEditor *automation_editor;
+
+  automation_editor = AGS_AUTOMATION_EDITOR(gtk_widget_get_ancestor(GTK_WIDGET(automation_toolbar),
+								    AGS_TYPE_AUTOMATION_EDITOR));
+
+  if(gtk_check_menu_item_get_active(widget)){
+    automation_editor->flags |= AGS_AUTOMATION_EDITOR_PASTE_NO_DUPLICATES;
+  }else{
+    automation_editor->flags &= (~AGS_AUTOMATION_EDITOR_PASTE_NO_DUPLICATES);
+  }
+}
+
 void
 ags_automation_toolbar_tool_popup_select_acceleration_callback(GtkWidget *item, AgsAutomationToolbar *automation_toolbar)
 {
@@ -158,40 +184,80 @@ ags_automation_toolbar_zoom_callback(GtkComboBox *combo_box, AgsAutomationToolba
   GtkWidget *widget;
   
   GtkAdjustment *adjustment;
-  
-  guint history;
 
+  GList *list_start;
+  
+  double zoom_factor, zoom;
+
+  auto void ags_automation_toolbar_zoom_callback_apply(GList *list);
+  
+  void ags_automation_toolbar_zoom_callback_apply(GList *list){
+    AgsAutomationEdit *automation_edit;
+    
+    while(list != NULL){
+      automation_edit = list->data;
+      
+      gtk_widget_queue_draw(automation_edit);
+      
+      /* reset ruler */
+      automation_edit->ruler->factor = zoom_factor;
+      automation_edit->ruler->precision = zoom;
+      automation_edit->ruler->scale_precision = 1.0 / zoom;
+  
+      gtk_widget_queue_draw((GtkWidget *) automation_edit->ruler);
+
+      list = list->next;
+    }
+  }
+  
   automation_editor = (AgsAutomationEditor *) gtk_widget_get_ancestor((GtkWidget *) automation_toolbar,
 								      AGS_TYPE_AUTOMATION_EDITOR);
-
-  history = gtk_combo_box_get_active(combo_box);
-
-  automation_toolbar->zoom_history = history;
-
-  /* refresh automation edit */
-  if(automation_editor->current_audio_automation_edit != NULL){
-    AGS_AUTOMATION_EDIT(automation_editor->current_audio_automation_edit)->flags |= AGS_AUTOMATION_EDIT_RESETING_HORIZONTALLY;
-    ags_automation_edit_reset_horizontally((AgsAutomationEdit *) automation_editor->current_audio_automation_edit,
-					   AGS_AUTOMATION_EDIT_RESET_HSCROLLBAR |
-					   AGS_AUTOMATION_EDIT_RESET_WIDTH);
-    AGS_AUTOMATION_EDIT(automation_editor->current_audio_automation_edit)->flags &= (~AGS_AUTOMATION_EDIT_RESETING_HORIZONTALLY);
-  }
   
-  if(automation_editor->current_output_automation_edit != NULL){
-    AGS_AUTOMATION_EDIT(automation_editor->current_output_automation_edit)->flags |= AGS_AUTOMATION_EDIT_RESETING_HORIZONTALLY;
-    ags_automation_edit_reset_horizontally((AgsAutomationEdit *) automation_editor->current_output_automation_edit,
-					   AGS_AUTOMATION_EDIT_RESET_HSCROLLBAR |
-					   AGS_AUTOMATION_EDIT_RESET_WIDTH);
-    AGS_AUTOMATION_EDIT(automation_editor->current_output_automation_edit)->flags &= (~AGS_AUTOMATION_EDIT_RESETING_HORIZONTALLY);
-  }
+  /* zoom */
+  zoom_factor = exp2(6.0 - (double) gtk_combo_box_get_active((GtkComboBox *) automation_toolbar->zoom));
+  zoom = exp2((double) gtk_combo_box_get_active((GtkComboBox *) automation_toolbar->zoom) - 2.0);
 
-  if(automation_editor->current_input_automation_edit != NULL){
-    AGS_AUTOMATION_EDIT(automation_editor->current_input_automation_edit)->flags |= AGS_AUTOMATION_EDIT_RESETING_HORIZONTALLY;
-    ags_automation_edit_reset_horizontally((AgsAutomationEdit *) automation_editor->current_input_automation_edit,
-					   AGS_AUTOMATION_EDIT_RESET_HSCROLLBAR |
-					   AGS_AUTOMATION_EDIT_RESET_WIDTH);
-    AGS_AUTOMATION_EDIT(automation_editor->current_input_automation_edit)->flags &= (~AGS_AUTOMATION_EDIT_RESETING_HORIZONTALLY);
-  }
+  /* audio */
+  automation_editor->audio_ruler->factor = zoom_factor;
+  automation_editor->audio_ruler->precision = zoom;
+  automation_editor->audio_ruler->scale_precision = 1.0 / zoom;
+  
+  gtk_widget_queue_draw((GtkWidget *) automation_editor->audio_ruler);
+
+  list_start = gtk_container_get_children(automation_editor->audio_scrolled_automation_edit_box->automation_edit_box);
+  ags_automation_toolbar_zoom_callback_apply(list_start);
+
+  g_list_free(list_start);
+
+  ags_automation_editor_reset_audio_scrollbar(automation_editor);
+
+  /* output */
+  automation_editor->output_ruler->factor = zoom_factor;
+  automation_editor->output_ruler->precision = zoom;
+  automation_editor->output_ruler->scale_precision = 1.0 / zoom;
+  
+  gtk_widget_queue_draw((GtkWidget *) automation_editor->output_ruler);
+
+  list_start = gtk_container_get_children(automation_editor->output_scrolled_automation_edit_box->automation_edit_box);
+  ags_automation_toolbar_zoom_callback_apply(list_start);
+
+  g_list_free(list_start);
+
+  ags_automation_editor_reset_output_scrollbar(automation_editor);
+
+  /* input */
+  automation_editor->input_ruler->factor = zoom_factor;
+  automation_editor->input_ruler->precision = zoom;
+  automation_editor->input_ruler->scale_precision = 1.0 / zoom;
+  
+  gtk_widget_queue_draw((GtkWidget *) automation_editor->input_ruler);
+
+  list_start = gtk_container_get_children(automation_editor->input_scrolled_automation_edit_box->automation_edit_box);
+  ags_automation_toolbar_zoom_callback_apply(list_start);
+
+  g_list_free(list_start);
+
+  ags_automation_editor_reset_input_scrollbar(automation_editor);
 }
 
 void
@@ -201,8 +267,11 @@ ags_automation_toolbar_port_callback(GtkComboBox *combo_box,
   GtkTreeModel *model;
   GtkTreeIter iter;
 
+  gchar *scope;
   gchar *control_name;
 
+  GType channel_type;
+  
   GValue value = {0,};
 
   if((AGS_AUTOMATION_TOOLBAR_RESET_PORT & (automation_toolbar->flags)) != 0){
@@ -216,15 +285,27 @@ ags_automation_toolbar_port_callback(GtkComboBox *combo_box,
 
   gtk_tree_model_get(model,
 		     &iter,
-		     1, &control_name,
+		     1, &scope,
+		     2, &control_name,
 		     -1);
 
+  if(!g_strcmp0("audio",
+		scope)){
+    channel_type = G_TYPE_NONE;
+  }else if(!g_strcmp0("output",
+		      scope)){
+    channel_type = AGS_TYPE_OUTPUT;
+  }else if(!g_strcmp0("input",
+		      scope)){
+    channel_type = AGS_TYPE_INPUT;
+  }
+
   if(control_name != NULL &&
      g_ascii_strncasecmp(control_name,
 			 "",
 			 1)){
     ags_automation_toolbar_apply_port(automation_toolbar,
-				      control_name);
+				      channel_type, control_name);
   }
   
   automation_toolbar->flags &= (~AGS_AUTOMATION_TOOLBAR_RESET_PORT);
