@@ -19,13 +19,65 @@
 
 #include <ags/X/editor/ags_envelope_editor_callbacks.h>
 
+#include <ags/object/ags_application_context.h>
+
+#include <ags/thread/ags_mutex_manager.h>
+
 #include <ags/audio/ags_audio.h>
 #include <ags/audio/ags_preset.h>
 
+#include <ags/X/ags_window.h>
+#include <ags/X/ags_machine.h>
+
 #include <ags/X/editor/ags_envelope_dialog.h>
 
 #include <ags/i18n.h>
 
+pthread_mutex_t* ags_envelope_editor_get_audio_mutex(AgsEnvelopeInfo *envelope_editor);
+
+pthread_mutex_t*
+ags_envelope_editor_get_audio_mutex(AgsEnvelopeInfo *envelope_editor)
+{
+  AgsEnvelopeDialog *envelope_dialog;
+
+  AgsWindow *window;
+  AgsMachine *machine;
+
+  AgsAudio *audio;
+
+  AgsMutexManager *mutex_manager;
+  
+  AgsApplicationContext *application_context;
+
+  pthread_mutex_t *application_mutex;
+  pthread_mutex_t *audio_mutex;
+
+  envelope_dialog = (AgsEnvelopeDialog *) gtk_widget_get_ancestor(envelope_editor,
+								  AGS_TYPE_ENVELOPE_DIALOG);
+
+  window = (AgsWindow *) gtk_widget_get_ancestor((GtkWidget *) envelope_dialog->machine,
+						 AGS_TYPE_WINDOW);
+  machine = envelope_dialog->machine;
+
+  audio = machine->audio;
+
+  /* application context and mutex manager */
+  application_context = window->application_context;
+
+  mutex_manager = ags_mutex_manager_get_instance();
+  application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);
+
+  /* get audio mutex */
+  pthread_mutex_lock(application_mutex);
+
+  audio_mutex = ags_mutex_manager_lookup(mutex_manager,
+					 (GObject *) audio);
+  
+  pthread_mutex_unlock(application_mutex);
+
+  return(audio_mutex);
+}
+
 void
 ags_envelope_editor_preset_callback(GtkWidget *combo_box,
 				    AgsEnvelopeEditor *envelope_editor)
@@ -70,9 +122,17 @@ void
 ags_envelope_editor_preset_remove_callback(GtkWidget *button,
 					   AgsEnvelopeEditor *envelope_editor)
 {
+  AgsEnvelopeDialog *envelope_dialog;
+
+  envelope_dialog = (AgsEnvelopeDialog *) gtk_widget_get_ancestor(envelope_editor,
+								  AGS_TYPE_ENVELOPE_DIALOG);
+  
   /* remove preset */
   ags_envelope_editor_remove_preset(envelope_editor,
 				    gtk_combo_box_get_active(envelope_editor->preset));
+
+  /* load preset */
+  ags_envelope_dialog_load_preset(envelope_dialog);
 }
 
 void
@@ -80,8 +140,13 @@ ags_envelope_editor_preset_rename_response_callback(GtkWidget *widget, gint resp
 						    AgsEnvelopeEditor *envelope_editor)
 {
   if(response == GTK_RESPONSE_ACCEPT){
+    AgsEnvelopeDialog *envelope_dialog;
+    
     gchar *text;
 
+    envelope_dialog = (AgsEnvelopeDialog *) gtk_widget_get_ancestor(envelope_editor,
+								    AGS_TYPE_ENVELOPE_DIALOG);
+
     /* get name */
     text = gtk_editable_get_chars(GTK_EDITABLE(gtk_container_get_children((GtkContainer *) GTK_DIALOG(widget)->vbox)->data),
 				  0, -1);
@@ -91,7 +156,7 @@ ags_envelope_editor_preset_rename_response_callback(GtkWidget *widget, gint resp
 				   text);
     
     /* load preset */
-    ags_envelope_editor_load_preset(envelope_editor);    
+    ags_envelope_dialog_load_preset(envelope_dialog);
   }
   
   envelope_editor->rename = NULL;
@@ -113,6 +178,8 @@ ags_envelope_editor_attack_x_callback(GtkWidget *range, AgsEnvelopeEditor *envel
 
   GError *error;
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -123,6 +190,8 @@ ags_envelope_editor_attack_x_callback(GtkWidget *range, AgsEnvelopeEditor *envel
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   attack_x = gtk_range_get_value((GtkRange *) range);
@@ -130,6 +199,8 @@ ags_envelope_editor_attack_x_callback(GtkWidget *range, AgsEnvelopeEditor *envel
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "attack", &value,
@@ -138,18 +209,21 @@ ags_envelope_editor_attack_x_callback(GtkWidget *range, AgsEnvelopeEditor *envel
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  attack_x + val[0][1]);
+  val[0][0] = attack_x;
 
   ags_preset_add_parameter(preset,
 			   "attack", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
@@ -167,6 +241,8 @@ ags_envelope_editor_attack_y_callback(GtkWidget *range, AgsEnvelopeEditor *envel
 
   GError *error;
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -177,6 +253,8 @@ ags_envelope_editor_attack_y_callback(GtkWidget *range, AgsEnvelopeEditor *envel
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   attack_y = gtk_range_get_value((GtkRange *) range);
@@ -184,6 +262,8 @@ ags_envelope_editor_attack_y_callback(GtkWidget *range, AgsEnvelopeEditor *envel
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "attack", &value,
@@ -192,18 +272,21 @@ ags_envelope_editor_attack_y_callback(GtkWidget *range, AgsEnvelopeEditor *envel
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  val[0][1] + attack_y * I);
+  val[0][1] = attack_y;
 
   ags_preset_add_parameter(preset,
 			   "attack", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
@@ -221,6 +304,8 @@ ags_envelope_editor_decay_x_callback(GtkWidget *range, AgsEnvelopeEditor *envelo
 
   GError *error;  
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -231,6 +316,8 @@ ags_envelope_editor_decay_x_callback(GtkWidget *range, AgsEnvelopeEditor *envelo
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   decay_x = gtk_range_get_value((GtkRange *) range);
@@ -238,6 +325,8 @@ ags_envelope_editor_decay_x_callback(GtkWidget *range, AgsEnvelopeEditor *envelo
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "decay", &value,
@@ -246,18 +335,21 @@ ags_envelope_editor_decay_x_callback(GtkWidget *range, AgsEnvelopeEditor *envelo
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  decay_x + val[0][1]);
+  val[0][0] = decay_x;
 
   ags_preset_add_parameter(preset,
 			   "decay", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
@@ -275,6 +367,8 @@ ags_envelope_editor_decay_y_callback(GtkWidget *range, AgsEnvelopeEditor *envelo
 
   GError *error;  
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -285,6 +379,8 @@ ags_envelope_editor_decay_y_callback(GtkWidget *range, AgsEnvelopeEditor *envelo
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   decay_y = gtk_range_get_value((GtkRange *) range);
@@ -292,6 +388,8 @@ ags_envelope_editor_decay_y_callback(GtkWidget *range, AgsEnvelopeEditor *envelo
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "decay", &value,
@@ -300,18 +398,21 @@ ags_envelope_editor_decay_y_callback(GtkWidget *range, AgsEnvelopeEditor *envelo
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  val[0][1] + decay_y * I);
+  val[0][1] = decay_y;
 
   ags_preset_add_parameter(preset,
 			   "decay", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
@@ -329,6 +430,8 @@ ags_envelope_editor_sustain_x_callback(GtkWidget *range, AgsEnvelopeEditor *enve
 
   GError *error;  
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -339,6 +442,8 @@ ags_envelope_editor_sustain_x_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   sustain_x = gtk_range_get_value((GtkRange *) range);
@@ -346,6 +451,8 @@ ags_envelope_editor_sustain_x_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "sustain", &value,
@@ -354,18 +461,21 @@ ags_envelope_editor_sustain_x_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  sustain_x + val[0][1]);
+  val[0][0] = sustain_x;
 
   ags_preset_add_parameter(preset,
 			   "sustain", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
@@ -383,6 +493,8 @@ ags_envelope_editor_sustain_y_callback(GtkWidget *range, AgsEnvelopeEditor *enve
 
   GError *error;  
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -393,6 +505,8 @@ ags_envelope_editor_sustain_y_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   sustain_y = gtk_range_get_value((GtkRange *) range);
@@ -400,6 +514,8 @@ ags_envelope_editor_sustain_y_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "sustain", &value,
@@ -408,18 +524,21 @@ ags_envelope_editor_sustain_y_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  val[0][1] + sustain_y * I);
+  val[0][1] = sustain_y;
 
   ags_preset_add_parameter(preset,
 			   "sustain", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
@@ -437,6 +556,8 @@ ags_envelope_editor_release_x_callback(GtkWidget *range, AgsEnvelopeEditor *enve
 
   GError *error;  
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -447,6 +568,8 @@ ags_envelope_editor_release_x_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   release_x = gtk_range_get_value((GtkRange *) range);
@@ -454,6 +577,8 @@ ags_envelope_editor_release_x_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "release", &value,
@@ -462,18 +587,21 @@ ags_envelope_editor_release_x_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  release_x + val[0][1]);
+  val[0][0] = release_x;
 
   ags_preset_add_parameter(preset,
 			   "release", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
@@ -491,6 +619,8 @@ ags_envelope_editor_release_y_callback(GtkWidget *range, AgsEnvelopeEditor *enve
 
   GError *error;  
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -501,6 +631,8 @@ ags_envelope_editor_release_y_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   release_y = gtk_range_get_value((GtkRange *) range);
@@ -508,6 +640,8 @@ ags_envelope_editor_release_y_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "release", &value,
@@ -516,18 +650,21 @@ ags_envelope_editor_release_y_callback(GtkWidget *range, AgsEnvelopeEditor *enve
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  val[0][1] + release_y * I);
-
+  val[0][1] = release_y;
+  
   ags_preset_add_parameter(preset,
 			   "release", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
@@ -545,6 +682,8 @@ ags_envelope_editor_ratio_callback(GtkWidget *range, AgsEnvelopeEditor *envelope
 
   GError *error;  
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_ENVELOPE_EDITOR_NO_UPDATE & (envelope_editor->flags)) != 0){
     return;
   }
@@ -555,6 +694,8 @@ ags_envelope_editor_ratio_callback(GtkWidget *range, AgsEnvelopeEditor *envelope
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_envelope_editor_get_audio_mutex(envelope_editor);
   
   /* get value and update preset */
   ratio = gtk_range_get_value((GtkRange *) range);
@@ -562,6 +703,8 @@ ags_envelope_editor_ratio_callback(GtkWidget *range, AgsEnvelopeEditor *envelope
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "ratio", &value,
@@ -570,18 +713,21 @@ ags_envelope_editor_ratio_callback(GtkWidget *range, AgsEnvelopeEditor *envelope
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  ratio * I);
+  val[0][1] = ratio;
 
   ags_preset_add_parameter(preset,
 			   "ratio", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_envelope_editor_plot(envelope_editor);
 }
