@@ -222,79 +222,6 @@ ags_machine_selection_load_defaults(AgsMachineSelection *machine_selection)
   }
 }
 
-/**
- * ags_machine_selection_run:
- * @machine_selection: the #AgsMachineSelection
- *
- * Run the dialog. Don't use this function you block all threads.
- *
- * Returns: the #AgsMachine
- */
-//FIXME:JK: don't do this
-AgsMachine*
-ags_machine_selection_run(AgsMachineSelection *machine_selection)
-{
-  AgsMachine *machine;
-  AgsMachineSelector *machine_selector;
-  AgsMachineRadioButton *machine_radio_button;
-  GtkVBox *vbox;
-  GtkRadioButton *group;
-  GList *list, *list_start;
-  gint response;
-
-  machine_selector = machine_selection->window->editor->machine_selector;
-
-  ags_machine_selection_load_defaults(machine_selection);
-  gtk_widget_show_all((GtkWidget *) GTK_DIALOG(machine_selection)->vbox);
-
-  response = gtk_dialog_run(GTK_DIALOG(machine_selection));
-
-  machine = NULL;
-
-  if(response == GTK_RESPONSE_ACCEPT){
-    list_start = 
-      list = gtk_container_get_children((GtkContainer *) vbox);
-
-    while(list != NULL){
-      if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(list->data))){
-	machine = g_object_get_data(list->data,
-				    AGS_MACHINE_SELECTION_INDEX);
-	  
-	break;
-      }
-      
-      list = list->next;
-    }
-
-    g_list_free(list_start);
-
-    machine_radio_button = NULL;
-    list_start =
-      list = gtk_container_get_children(GTK_CONTAINER(machine_selector));
-    list = list->next;
-
-    while(list != NULL){
-      if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(list->data))){
-	machine_radio_button = AGS_MACHINE_RADIO_BUTTON(list->data);
-
-	break;
-      }
-
-      list = list->next;
-    }
-
-    g_list_free(list_start);
-
-    g_object_set(G_OBJECT(machine_radio_button),
-		 "machine", machine,
-		 NULL);
-  }
-
-  gtk_widget_destroy((GtkWidget *) machine_selection);
-
-  return(machine);
-}
-
 /**
  * ags_machine_selection_new:
  * @window: the #AgsWindow
