@@ -284,65 +284,7 @@ ags_machine_selector_remove_index(AgsMachineSelector *machine_selector,
 
   if(machine_radio_button == NULL){
     return;
-  }
-  
-  /*  */
-  notation_editor = (AgsNotationEditor *) gtk_widget_get_ancestor((GtkWidget *) machine_selector,
-								  AGS_TYPE_NOTATION_EDITOR);
-
-  if(notation_editor == NULL){
-    automation_editor = (AgsAutomationEditor *) gtk_widget_get_ancestor((GtkWidget *) machine_selector,
-									AGS_TYPE_AUTOMATION_EDITOR);
-
-    if(automation_editor != NULL){
-      /* destroy edit widgets */
-      if(machine_radio_button->machine != NULL){
-	AgsAutomationEditorChild *automation_editor_child;
-
-	automation_editor_child = NULL;
-	
-	list = automation_editor->automation_editor_child;
-
-	while(list != NULL){
-	  if(AGS_AUTOMATION_EDITOR_CHILD(list->data)->machine == machine_radio_button->machine){
-	    automation_editor_child = AGS_AUTOMATION_EDITOR_CHILD(list->data);
-	    
-	    gtk_widget_destroy((GtkWidget *) automation_editor_child->audio_scale);
-	    gtk_widget_destroy((GtkWidget *) automation_editor_child->audio_automation_edit);
-	    
-	    gtk_widget_destroy((GtkWidget *) automation_editor_child->output_scale);
-	    gtk_widget_destroy((GtkWidget *) automation_editor_child->output_notebook);
-	    gtk_widget_destroy((GtkWidget *) automation_editor_child->output_automation_edit);
-
-	    gtk_widget_destroy((GtkWidget *) automation_editor_child->input_scale);
-	    gtk_widget_destroy((GtkWidget *) automation_editor_child->input_notebook);
-	    gtk_widget_destroy((GtkWidget *) automation_editor_child->input_automation_edit);
-
-	    automation_editor->current_audio_scale = NULL;
-	    automation_editor->current_audio_automation_edit = NULL;
-
-	    automation_editor->current_output_notebook = NULL;
-	    automation_editor->current_output_scale = NULL;
-	    automation_editor->current_output_automation_edit = NULL;
-
-	    automation_editor->current_input_notebook = NULL;
-	    automation_editor->current_input_scale = NULL;
-	    automation_editor->current_input_automation_edit = NULL;
-
-	    break;
-	  }
-    
-	  list = list->next;
-	}
-
-	if(automation_editor_child != NULL){
-	  automation_editor->automation_editor_child = g_list_remove(automation_editor->automation_editor_child,
-								     automation_editor_child);
-	  free(automation_editor_child);
-	}
-      }
-    }
-  }
+  }  
   
   /**/
   gtk_widget_destroy(GTK_WIDGET(machine_radio_button));
