@@ -19,13 +19,65 @@
 
 #include <ags/X/editor/ags_pattern_envelope_callbacks.h>
 
+#include <ags/object/ags_application_context.h>
+
+#include <ags/thread/ags_mutex_manager.h>
+
 #include <ags/audio/ags_audio.h>
 #include <ags/audio/ags_preset.h>
 
+#include <ags/X/ags_window.h>
+#include <ags/X/ags_machine.h>
+
 #include <ags/X/editor/ags_envelope_dialog.h>
 
 #include <ags/i18n.h>
 
+pthread_mutex_t* ags_pattern_envelope_get_audio_mutex(AgsPatternEnvelope *pattern_envelope);
+
+pthread_mutex_t*
+ags_pattern_envelope_get_audio_mutex(AgsPatternEnvelope *pattern_envelope)
+{
+  AgsEnvelopeDialog *envelope_dialog;
+
+  AgsWindow *window;
+  AgsMachine *machine;
+
+  AgsAudio *audio;
+
+  AgsMutexManager *mutex_manager;
+  
+  AgsApplicationContext *application_context;
+
+  pthread_mutex_t *application_mutex;
+  pthread_mutex_t *audio_mutex;
+
+  envelope_dialog = (AgsEnvelopeDialog *) gtk_widget_get_ancestor(pattern_envelope,
+								  AGS_TYPE_ENVELOPE_DIALOG);
+
+  window = (AgsWindow *) gtk_widget_get_ancestor((GtkWidget *) envelope_dialog->machine,
+						 AGS_TYPE_WINDOW);
+  machine = envelope_dialog->machine;
+
+  audio = machine->audio;
+
+  /* application context and mutex manager */
+  application_context = window->application_context;
+
+  mutex_manager = ags_mutex_manager_get_instance();
+  application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);
+
+  /* get audio mutex */
+  pthread_mutex_lock(application_mutex);
+
+  audio_mutex = ags_mutex_manager_lookup(mutex_manager,
+					 (GObject *) audio);
+  
+  pthread_mutex_unlock(application_mutex);
+
+  return(audio_mutex);
+}
+
 void
 ags_pattern_envelope_edit_callback(GtkCellRendererToggle *cell_renderer,
 				   gchar *path_str,
@@ -121,6 +173,8 @@ ags_pattern_envelope_audio_channel_start_callback(GtkWidget *spin_button,
 {
   AgsPreset *preset;
   
+  GValue value = {0,};
+
   guint audio_channel_start;
 
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
@@ -136,12 +190,15 @@ ags_pattern_envelope_audio_channel_start_callback(GtkWidget *spin_button,
 
   /* set property */
   audio_channel_start = gtk_spin_button_get_value_as_int((GtkSpinButton *) spin_button);
-  g_object_set(preset,
-	       "audio-channel-start", audio_channel_start,
-	       NULL);
 
-  /* reset */
-  ags_pattern_envelope_reset_tree_view(pattern_envelope);
+  g_value_init(&value,
+	       G_TYPE_UINT);
+  g_value_set_uint(&value,
+		   audio_channel_start);
+
+  ags_pattern_envelope_set_preset_property(pattern_envelope,
+					   preset,
+					   "audio-channel-start", &value);
 }
 
 void
@@ -149,13 +206,11 @@ ags_pattern_envelope_audio_channel_end_callback(GtkWidget *spin_button,
 						AgsPatternEnvelope *pattern_envelope)
 {
   AgsPreset *preset;
-  
+
   guint audio_channel_end;
 
   GValue value = {0,};
 
-  GError *error;
-
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -169,12 +224,15 @@ ags_pattern_envelope_audio_channel_end_callback(GtkWidget *spin_button,
 
   /* set property */
   audio_channel_end = gtk_spin_button_get_value_as_int((GtkSpinButton *) spin_button);
-  g_object_set(preset,
-	       "audio-channel-end", audio_channel_end,
-	       NULL);
 
-  /* reset */
-  ags_pattern_envelope_reset_tree_view(pattern_envelope);
+  g_value_init(&value,
+	       G_TYPE_UINT);
+  g_value_set_uint(&value,
+		   audio_channel_end);
+
+  ags_pattern_envelope_set_preset_property(pattern_envelope,
+					   preset,
+					   "audio-channel-end", &value);
 }
 
 void
@@ -187,8 +245,6 @@ ags_pattern_envelope_pad_start_callback(GtkWidget *spin_button,
 
   GValue value = {0,};
 
-  GError *error;
-
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -202,12 +258,15 @@ ags_pattern_envelope_pad_start_callback(GtkWidget *spin_button,
 
   /* set property */
   pad_start = gtk_spin_button_get_value_as_int((GtkSpinButton *) spin_button);
-  g_object_set(preset,
-	       "pad-start", pad_start,
-	       NULL);
 
-  /* reset */
-  ags_pattern_envelope_reset_tree_view(pattern_envelope);
+  g_value_init(&value,
+	       G_TYPE_UINT);
+  g_value_set_uint(&value,
+		   pad_start);
+
+  ags_pattern_envelope_set_preset_property(pattern_envelope,
+					   preset,
+					   "pad-start", &value);
 }
 
 void
@@ -220,8 +279,6 @@ ags_pattern_envelope_pad_end_callback(GtkWidget *spin_button,
 
   GValue value = {0,};
 
-  GError *error;
-
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -235,12 +292,15 @@ ags_pattern_envelope_pad_end_callback(GtkWidget *spin_button,
 
   /* set property */
   pad_end = gtk_spin_button_get_value_as_int((GtkSpinButton *) spin_button);
-  g_object_set(preset,
-	       "pad-end", pad_end,
-	       NULL);
 
-  /* reset */
-  ags_pattern_envelope_reset_tree_view(pattern_envelope);
+  g_value_init(&value,
+	       G_TYPE_UINT);
+  g_value_set_uint(&value,
+		   pad_end);
+
+  ags_pattern_envelope_set_preset_property(pattern_envelope,
+					   preset,
+					   "pad-end", &value);
 }
 
 void
@@ -253,8 +313,6 @@ ags_pattern_envelope_x_start_callback(GtkWidget *spin_button,
 
   GValue value = {0,};
 
-  GError *error;
-
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -268,12 +326,15 @@ ags_pattern_envelope_x_start_callback(GtkWidget *spin_button,
 
   /* set property */
   x_start = gtk_spin_button_get_value_as_int((GtkSpinButton *) spin_button);
-  g_object_set(preset,
-	       "x-start", x_start,
-	       NULL);
 
-  /* reset */
-  ags_pattern_envelope_reset_tree_view(pattern_envelope);
+  g_value_init(&value,
+	       G_TYPE_UINT);
+  g_value_set_uint(&value,
+		   x_start);
+
+  ags_pattern_envelope_set_preset_property(pattern_envelope,
+					   preset,
+					   "x-start", &value);
 }
 
 void
@@ -286,8 +347,6 @@ ags_pattern_envelope_x_end_callback(GtkWidget *spin_button,
 
   GValue value = {0,};
 
-  GError *error;
-
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -301,12 +360,15 @@ ags_pattern_envelope_x_end_callback(GtkWidget *spin_button,
 
   /* set property */
   x_end = gtk_spin_button_get_value_as_int((GtkSpinButton *) spin_button);
-  g_object_set(preset,
-	       "x-end", x_end,
-	       NULL);
 
-  /* reset */
-  ags_pattern_envelope_reset_tree_view(pattern_envelope);
+  g_value_init(&value,
+	       G_TYPE_UINT);
+  g_value_set_uint(&value,
+		   x_end);
+
+  ags_pattern_envelope_set_preset_property(pattern_envelope,
+					   preset,
+					   "x-end", &value);
 }
 
 void
@@ -323,6 +385,8 @@ ags_pattern_envelope_attack_x_callback(GtkWidget *range,
 
   GError *error;
 
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -333,6 +397,8 @@ ags_pattern_envelope_attack_x_callback(GtkWidget *range,
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
   
   /* get value and update preset */
   attack_x = gtk_range_get_value(GTK_RANGE(range));
@@ -340,6 +406,8 @@ ags_pattern_envelope_attack_x_callback(GtkWidget *range,
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "attack", &value,
@@ -348,6 +416,8 @@ ags_pattern_envelope_attack_x_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
@@ -359,6 +429,8 @@ ags_pattern_envelope_attack_x_callback(GtkWidget *range,
   ags_preset_add_parameter(preset,
 			   "attack", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -376,7 +448,9 @@ ags_pattern_envelope_attack_y_callback(GtkWidget *range,
   GValue value = {0,};
 
   GError *error;
-  
+
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -387,6 +461,8 @@ ags_pattern_envelope_attack_y_callback(GtkWidget *range,
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
   
   /* get value and update preset */
   attack_y = gtk_range_get_value((GtkRange *) range);
@@ -394,6 +470,8 @@ ags_pattern_envelope_attack_y_callback(GtkWidget *range,
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "attack", &value,
@@ -402,6 +480,8 @@ ags_pattern_envelope_attack_y_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
@@ -413,6 +493,8 @@ ags_pattern_envelope_attack_y_callback(GtkWidget *range,
   ags_preset_add_parameter(preset,
 			   "attack", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -430,6 +512,8 @@ ags_pattern_envelope_decay_x_callback(GtkWidget *range,
   GValue value = {0,};
 
   GError *error;
+
+  pthread_mutex_t *audio_mutex;
   
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
@@ -441,6 +525,8 @@ ags_pattern_envelope_decay_x_callback(GtkWidget *range,
   if(preset == NULL){
     return;
   }
+
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
   
   /* get value and update preset */
   decay_x = gtk_range_get_value((GtkRange *) range);
@@ -448,6 +534,8 @@ ags_pattern_envelope_decay_x_callback(GtkWidget *range,
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "decay", &value,
@@ -456,18 +544,21 @@ ags_pattern_envelope_decay_x_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  decay_x + I * val[0][1]);
+  val[0][0] = decay_x;
 
   ags_preset_add_parameter(preset,
 			   "decay", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -486,6 +577,8 @@ ags_pattern_envelope_decay_y_callback(GtkWidget *range,
 
   GError *error;
   
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -497,12 +590,16 @@ ags_pattern_envelope_decay_y_callback(GtkWidget *range,
     return;
   }
   
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
+
   /* get value and update preset */
   decay_y = gtk_range_get_value((GtkRange *) range);
 
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "decay", &value,
@@ -511,18 +608,21 @@ ags_pattern_envelope_decay_y_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  val[0][0] + decay_y * I);
-
+  val[0][1] = decay_y;
+  
   ags_preset_add_parameter(preset,
 			   "decay", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -540,6 +640,8 @@ ags_pattern_envelope_sustain_x_callback(GtkWidget *range,
   GValue value = {0,};
 
   GError *error;
+
+  pthread_mutex_t *audio_mutex;
   
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
@@ -552,12 +654,16 @@ ags_pattern_envelope_sustain_x_callback(GtkWidget *range,
     return;
   }
   
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
+
   /* get value and update preset */
   sustain_x = gtk_range_get_value((GtkRange *) range);
 
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "sustain", &value,
@@ -566,18 +672,21 @@ ags_pattern_envelope_sustain_x_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  sustain_x + I * val[0][1]);
-
+  val[0][0] = sustain_x;
+  
   ags_preset_add_parameter(preset,
 			   "sustain", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -595,6 +704,8 @@ ags_pattern_envelope_sustain_y_callback(GtkWidget *range,
   GValue value = {0,};
 
   GError *error;
+
+  pthread_mutex_t *audio_mutex;
   
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
@@ -607,12 +718,16 @@ ags_pattern_envelope_sustain_y_callback(GtkWidget *range,
     return;
   }
   
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
+
   /* get value and update preset */
   sustain_y = gtk_range_get_value((GtkRange *) range);
 
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "sustain", &value,
@@ -621,18 +736,21 @@ ags_pattern_envelope_sustain_y_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  val[0][0] + sustain_y * I);
-
+  val[0][1] = sustain_y;
+  
   ags_preset_add_parameter(preset,
 			   "sustain", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -651,6 +769,8 @@ ags_pattern_envelope_release_x_callback(GtkWidget *range,
 
   GError *error;
   
+  pthread_mutex_t *audio_mutex;
+
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
   }
@@ -662,12 +782,16 @@ ags_pattern_envelope_release_x_callback(GtkWidget *range,
     return;
   }
   
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
+
   /* get value and update preset */
   release_x = gtk_range_get_value((GtkRange *) range);
 
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "release", &value,
@@ -676,18 +800,21 @@ ags_pattern_envelope_release_x_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  release_x + I * val[0][1]);
-
+  val[0][0] = release_x;
+  
   ags_preset_add_parameter(preset,
 			   "release", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -705,6 +832,8 @@ ags_pattern_envelope_release_y_callback(GtkWidget *range,
   GValue value = {0,};
 
   GError *error;
+
+  pthread_mutex_t *audio_mutex;
   
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
@@ -717,12 +846,16 @@ ags_pattern_envelope_release_y_callback(GtkWidget *range,
     return;
   }
   
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
+
   /* get value and update preset */
   release_y = gtk_range_get_value((GtkRange *) range);
 
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "release", &value,
@@ -731,18 +864,21 @@ ags_pattern_envelope_release_y_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  val[0][0] + release_y * I);
-
+  val[0][1] = release_y;
+  
   ags_preset_add_parameter(preset,
 			   "release", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -760,6 +896,8 @@ ags_pattern_envelope_ratio_callback(GtkWidget *range,
   GValue value = {0,};
 
   GError *error;
+
+  pthread_mutex_t *audio_mutex;
   
   if((AGS_PATTERN_ENVELOPE_NO_UPDATE & (pattern_envelope->flags)) != 0){
     return;
@@ -772,12 +910,16 @@ ags_pattern_envelope_ratio_callback(GtkWidget *range,
     return;
   }
   
+  audio_mutex = ags_pattern_envelope_get_audio_mutex(pattern_envelope);
+
   /* get value and update preset */
   ratio = gtk_range_get_value((GtkRange *) range);
 
   g_value_init(&value,
 	       AGS_TYPE_COMPLEX);
 
+  pthread_mutex_lock(audio_mutex);
+
   error = NULL;
   ags_preset_get_parameter(preset,
 			   "ratio", &value,
@@ -786,18 +928,21 @@ ags_pattern_envelope_ratio_callback(GtkWidget *range,
   if(error != NULL){
     g_message("%s", error->message);
 
+    pthread_mutex_unlock(audio_mutex);
+
     return;
   }
   
   val = (AgsComplex *) g_value_get_boxed(&value);
 
   /* add parameter */
-  ags_complex_set(val,
-		  ratio * I);
+  val[0][1] = ratio;
 
   ags_preset_add_parameter(preset,
 			   "ratio", &value);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* plot */
   ags_pattern_envelope_plot(pattern_envelope);
 }
@@ -807,6 +952,8 @@ ags_pattern_envelope_preset_move_up_callback(GtkWidget *button,
 					     AgsPatternEnvelope *pattern_envelope)
 {
   AgsEnvelopeDialog *envelope_dialog;
+
+  AgsWindow *window;
   AgsMachine *machine;
 
   GtkTreeModel *model;
@@ -815,6 +962,10 @@ ags_pattern_envelope_preset_move_up_callback(GtkWidget *button,
   AgsAudio *audio;
   AgsPreset *current;
   
+  AgsMutexManager *mutex_manager;
+  
+  AgsApplicationContext *application_context;
+
   GList *preset, *prev;
 
   gchar *preset_name, *prev_name;
@@ -822,10 +973,16 @@ ags_pattern_envelope_preset_move_up_callback(GtkWidget *button,
   guint nth;
   gboolean do_edit;
 
+  pthread_mutex_t *application_mutex;
+  pthread_mutex_t *audio_mutex;
+
   envelope_dialog = (AgsEnvelopeDialog *) gtk_widget_get_ancestor(pattern_envelope,
 								  AGS_TYPE_ENVELOPE_DIALOG);
 
+  window = (AgsWindow *) gtk_widget_get_ancestor((GtkWidget *) envelope_dialog->machine,
+						 AGS_TYPE_WINDOW);
   machine = envelope_dialog->machine;
+
   audio = machine->audio;
 
   /* get model */
@@ -855,6 +1012,20 @@ ags_pattern_envelope_preset_move_up_callback(GtkWidget *button,
     return;
   }
 
+  /* application context and mutex manager */
+  application_context = window->application_context;
+
+  mutex_manager = ags_mutex_manager_get_instance();
+  application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);
+
+  /* get audio mutex */
+  pthread_mutex_lock(application_mutex);
+
+  audio_mutex = ags_mutex_manager_lookup(mutex_manager,
+					 (GObject *) audio);
+  
+  pthread_mutex_unlock(application_mutex);
+
   /* get prev and current preset name */
   gtk_tree_model_get(model, &iter,
 		     AGS_PATTERN_ENVELOPE_COLUMN_PRESET_NAME, &preset_name,
@@ -869,6 +1040,8 @@ ags_pattern_envelope_preset_move_up_callback(GtkWidget *button,
 		     -1);
 
   /* find preset */
+  pthread_mutex_lock(audio_mutex);
+
   preset = ags_preset_find_name(audio->preset,
 				preset_name);
 
@@ -884,9 +1057,11 @@ ags_pattern_envelope_preset_move_up_callback(GtkWidget *button,
   audio->preset = g_list_insert_before(audio->preset,
 				       prev,
 				       current);
+
+  pthread_mutex_unlock(audio_mutex);
   
   /* load preset */
-  ags_pattern_envelope_load_preset(pattern_envelope);    
+  ags_envelope_dialog_load_preset(envelope_dialog);    
 }
 
 void
@@ -894,6 +1069,8 @@ ags_pattern_envelope_preset_move_down_callback(GtkWidget *button,
 					       AgsPatternEnvelope *pattern_envelope)
 {
   AgsEnvelopeDialog *envelope_dialog;
+
+  AgsWindow *window;
   AgsMachine *machine;
 
   GtkTreeModel *model;
@@ -901,6 +1078,10 @@ ags_pattern_envelope_preset_move_down_callback(GtkWidget *button,
 
   AgsAudio *audio;
   AgsPreset *current;
+
+  AgsMutexManager *mutex_manager;
+  
+  AgsApplicationContext *application_context;
   
   GList *preset, *next;
 
@@ -909,10 +1090,16 @@ ags_pattern_envelope_preset_move_down_callback(GtkWidget *button,
   guint nth;
   gboolean do_edit;
 
+  pthread_mutex_t *application_mutex;
+  pthread_mutex_t *audio_mutex;
+
   envelope_dialog = (AgsEnvelopeDialog *) gtk_widget_get_ancestor(pattern_envelope,
 								  AGS_TYPE_ENVELOPE_DIALOG);
 
+  window = (AgsWindow *) gtk_widget_get_ancestor((GtkWidget *) envelope_dialog->machine,
+						 AGS_TYPE_WINDOW);
   machine = envelope_dialog->machine;
+
   audio = machine->audio;
 
   /* get model */
@@ -941,6 +1128,20 @@ ags_pattern_envelope_preset_move_down_callback(GtkWidget *button,
     return;
   }
 
+  /* application context and mutex manager */
+  application_context = window->application_context;
+
+  mutex_manager = ags_mutex_manager_get_instance();
+  application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);
+
+  /* get audio mutex */
+  pthread_mutex_lock(application_mutex);
+
+  audio_mutex = ags_mutex_manager_lookup(mutex_manager,
+					 (GObject *) audio);
+  
+  pthread_mutex_unlock(application_mutex);
+
   /* get next and current preset name */
   gtk_tree_model_get(model, &iter,
 		     AGS_PATTERN_ENVELOPE_COLUMN_PRESET_NAME, &preset_name,
@@ -955,6 +1156,8 @@ ags_pattern_envelope_preset_move_down_callback(GtkWidget *button,
 		     -1);
 
   /* find preset */
+  pthread_mutex_lock(audio_mutex);
+
   preset = ags_preset_find_name(audio->preset,
 				preset_name);
 
@@ -971,8 +1174,10 @@ ags_pattern_envelope_preset_move_down_callback(GtkWidget *button,
 				       preset,
 				       current);
 
+  pthread_mutex_unlock(audio_mutex);
+
   /* load preset */
-  ags_pattern_envelope_load_preset(pattern_envelope);    
+  ags_envelope_dialog_load_preset(envelope_dialog);    
 }
 
 void
@@ -1036,8 +1241,16 @@ ags_pattern_envelope_preset_remove_callback(GtkWidget *button,
   
   /* remove preset */
   if(do_edit){
+    AgsEnvelopeDialog *envelope_dialog;
+
+    envelope_dialog = (AgsEnvelopeDialog *) gtk_widget_get_ancestor(pattern_envelope,
+								    AGS_TYPE_ENVELOPE_DIALOG);
+    
     ags_pattern_envelope_remove_preset(pattern_envelope,
 				       nth);
+
+    /* load preset */
+    ags_envelope_dialog_load_preset(envelope_dialog);
   }
 }
 
@@ -1046,8 +1259,13 @@ ags_pattern_envelope_preset_rename_response_callback(GtkWidget *widget, gint res
 						     AgsPatternEnvelope *pattern_envelope)
 {
   if(response == GTK_RESPONSE_ACCEPT){
+    AgsEnvelopeDialog *envelope_dialog;
+    
     gchar *text;
 
+    envelope_dialog = (AgsEnvelopeDialog *) gtk_widget_get_ancestor(pattern_envelope,
+								    AGS_TYPE_ENVELOPE_DIALOG);
+
     /* get name */
     text = gtk_editable_get_chars(GTK_EDITABLE(gtk_container_get_children((GtkContainer *) GTK_DIALOG(widget)->vbox)->data),
 				  0, -1);
@@ -1057,7 +1275,7 @@ ags_pattern_envelope_preset_rename_response_callback(GtkWidget *widget, gint res
 				    text);
     
     /* load preset */
-    ags_pattern_envelope_load_preset(pattern_envelope);    
+    ags_envelope_dialog_load_preset(envelope_dialog);
   }
   
   pattern_envelope->rename = NULL;
