@@ -28,6 +28,8 @@
 #include <ags/X/ags_automation_editor.h>
 #include <ags/X/ags_machine.h>
 
+#include <ags/X/editor/ags_automation_edit.h>
+
 #include <ags/i18n.h>
 
 void ags_ramp_acceleration_dialog_class_init(AgsRampAccelerationDialogClass *ramp_acceleration_dialog);
@@ -531,9 +533,11 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
   AgsNotebook *notebook;
 
   AgsAudio *audio;
+  AgsAutomation *current;
   AgsAcceleration *acceleration;
 
   AgsMutexManager *mutex_manager;
+  AgsTimestamp *timestamp;
 
   AgsApplicationContext *application_context;
 
@@ -552,13 +556,16 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
   gdouble upper, lower, range, step;
   gdouble c_upper, c_lower, c_range;
 
+  guint tmp;
   guint x0, x1;
   gdouble y0, y1;
   guint step_count;
   gint line;
-  guint i;
+  guint i, i_start, i_stop;
+  guint nth_match, match_count;
 
   gboolean is_audio, is_output, is_input;
+  gboolean success;
   
   pthread_mutex_t *application_mutex;
   pthread_mutex_t *audio_mutex;
@@ -570,22 +577,27 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
 
   machine = automation_editor->selected_machine;
 
-  if(machine == NULL){
+  if(machine == NULL ||
+     automation_editor->focused_automation_edit == NULL){
     return;
   }
 
-  if(gtk_notebook_get_current_page(automation_editor->notebook) == 0){
+  automation_toolbar = automation_editor->automation_toolbar;
+  
+  specifier = gtk_combo_box_text_get_active_text(ramp_acceleration_dialog->port);
+
+  if(automation_editor->focused_automation_edit->channel_type == G_TYPE_NONE){
     notebook = NULL;
     channel_type = G_TYPE_NONE;
 
     is_audio = TRUE;
-  }else if(gtk_notebook_get_current_page(automation_editor->notebook) == 1){
-    notebook = automation_editor->current_output_notebook;
+  }else if(automation_editor->focused_automation_edit->channel_type == AGS_TYPE_OUTPUT){
+    notebook = automation_editor->output_notebook;
     channel_type = AGS_TYPE_OUTPUT;
       
     is_output = TRUE;
-  }else if(gtk_notebook_get_current_page(automation_editor->notebook) == 2){
-    notebook = automation_editor->current_input_notebook;
+  }else if(automation_editor->focused_automation_edit->channel_type == AGS_TYPE_INPUT){
+    notebook = automation_editor->input_notebook;
     channel_type = AGS_TYPE_INPUT;
       
     is_input = TRUE;
@@ -594,10 +606,10 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
   audio = machine->audio;
 
   /* get some values */
-  x0 = (AGS_RAMP_ACCELERATION_DEFAULT_WIDTH / 16) * gtk_spin_button_get_value_as_int(ramp_acceleration_dialog->ramp_x0);
+  x0 = AGS_AUTOMATION_EDIT_DEFAULT_CONTROL_WIDTH * gtk_spin_button_get_value_as_int(ramp_acceleration_dialog->ramp_x0);
   y0 = gtk_spin_button_get_value(ramp_acceleration_dialog->ramp_y0);
 
-  x1 = (AGS_RAMP_ACCELERATION_DEFAULT_WIDTH / 16) * gtk_spin_button_get_value_as_int(ramp_acceleration_dialog->ramp_x1);
+  x1 = AGS_AUTOMATION_EDIT_DEFAULT_CONTROL_WIDTH * gtk_spin_button_get_value_as_int(ramp_acceleration_dialog->ramp_x1);
   y1 = gtk_spin_button_get_value(ramp_acceleration_dialog->ramp_y1);
   
   step_count = gtk_spin_button_get_value_as_int(ramp_acceleration_dialog->ramp_step_count);
@@ -614,12 +626,13 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
   audio_mutex = ags_mutex_manager_lookup(mutex_manager,
 					 (GObject *) audio);
   
-  pthread_mutex_unlock(application_mutex);
+  pthread_mutex_unlock(application_mutex);  
 
   /* remove acceleration of region */
   line = 0;
   
-  while((line = ags_notebook_next_active_tab(notebook,
+  while(notebook == NULL ||
+	(line = ags_notebook_next_active_tab(notebook,
 					     line)) != -1){
     list_automation = audio->automation;
 
@@ -627,16 +640,28 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
 									      specifier,
 									      channel_type,
 									      line)) != NULL){
-      upper = AGS_AUTOMATION(list_automation->data)->upper;
-      lower = AGS_AUTOMATION(list_automation->data)->lower;
+      current = AGS_AUTOMATION(list_automation->data);
+
+      if(current->timestamp->timer.ags_offset.offset < x0){
+	list_automation = list_automation->next;
+	
+	continue;
+      }
+
+      if(current->timestamp->timer.ags_offset.offset > x1){
+	break;
+      }
+      
+      upper = current->upper;
+      lower = current->lower;
 	
       range = upper - lower;
 
-      if(AGS_PORT(AGS_AUTOMATION(list_automation->data)->port)->conversion != NULL){
-	c_upper = ags_conversion_convert(AGS_PORT(AGS_AUTOMATION(list_automation->data)->port)->conversion,
+      if(AGS_PORT(current->port)->conversion != NULL){
+	c_upper = ags_conversion_convert(AGS_PORT(current->port)->conversion,
 					 upper,
 					 FALSE);
-	c_lower = ags_conversion_convert(AGS_PORT(AGS_AUTOMATION(list_automation->data)->port)->conversion,
+	c_lower = ags_conversion_convert(AGS_PORT(current->port)->conversion,
 					 lower,
 					 FALSE);
 	c_range = c_upper - c_lower;
@@ -655,14 +680,14 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
       }
 	
       /* check steps */
-      gui_y = AGS_AUTOMATION(list_automation->data)->steps;
+      gui_y = current->steps;
 
-      val = c_lower + (gui_y * (c_range / AGS_AUTOMATION(list_automation->data)->steps));
+      val = c_lower + (gui_y * (c_range / current->steps));
       c_y0 = val;
 
       /* conversion */
-      if(AGS_PORT(AGS_AUTOMATION(list_automation->data)->port)->conversion != NULL){
-	c_y0 = ags_conversion_convert(AGS_PORT(AGS_AUTOMATION(list_automation->data)->port)->conversion,
+      if(AGS_PORT(current->port)->conversion != NULL){
+	c_y0 = ags_conversion_convert(AGS_PORT(current->port)->conversion,
 				      c_y0,
 				      TRUE);
       }
@@ -670,12 +695,12 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
       /* check steps */
       gui_y = 0;
 
-      val = c_lower + (gui_y * (c_range / AGS_AUTOMATION(list_automation->data)->steps));
+      val = c_lower + (gui_y * (c_range / current->steps));
       c_y1 = val;
 
       /* conversion */
-      if(AGS_PORT(AGS_AUTOMATION(list_automation->data)->port)->conversion != NULL){
-	c_y1 = ags_conversion_convert(AGS_PORT(AGS_AUTOMATION(list_automation->data)->port)->conversion,
+      if(AGS_PORT(current->port)->conversion != NULL){
+	c_y1 = ags_conversion_convert(AGS_PORT(current->port)->conversion,
 				      c_y1,
 				      TRUE);
       }
@@ -688,8 +713,8 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
 							     FALSE);
       
       while(list_acceleration != NULL){
-	AGS_AUTOMATION(list_automation->data)->acceleration = g_list_remove(AGS_AUTOMATION(list_automation->data)->acceleration,
-									    list_acceleration->data);
+	current->acceleration = g_list_remove(current->acceleration,
+					      list_acceleration->data);
 	
 	list_acceleration = list_acceleration->next;
       }
@@ -699,55 +724,261 @@ ags_ramp_acceleration_dialog_apply(AgsApplicable *applicable)
       list_automation = list_automation->next;
     }
 
+    if(notebook == NULL){
+      break;
+    }
+
     line++;
   }
   
   /* ramp acceleration */
-  automation_toolbar = automation_editor->automation_toolbar;
-  
-  specifier = gtk_combo_box_text_get_active_text(ramp_acceleration_dialog->port);
-  
   line = 0;
+
+  timestamp = ags_timestamp_new();
+
+  timestamp->flags &= (~AGS_TIMESTAMP_UNIX);
+  timestamp->flags |= AGS_TIMESTAMP_OFFSET;
   
-  while((line = ags_notebook_next_active_tab(notebook,
+  while(notebook == NULL ||
+	(line = ags_notebook_next_active_tab(notebook,
 					     line)) != -1){
-    list_automation = audio->automation;
+    AgsChannel *channel;
+    AgsPort *play_port, *recall_port;
 
-    while((list_automation = ags_automation_find_specifier_with_type_and_line(list_automation,
-									      specifier,
-									      channel_type,
-									      line)) != NULL){
-      upper = AGS_AUTOMATION(list_automation->data)->upper;
-      lower = AGS_AUTOMATION(list_automation->data)->lower;
+    guint j;
+    guint tmp;
+    
+    play_port = NULL;
+    recall_port = NULL;
+    
+    if(channel_type == AGS_TYPE_OUTPUT){
+      channel = ags_channel_nth(machine->audio->output,
+				line);
+
+      play_port = ags_channel_find_port_by_specifier_and_scope(channel,
+							       specifier, TRUE);
+
+      recall_port = ags_channel_find_port_by_specifier_and_scope(channel,
+								 specifier, FALSE);
+    }else if(channel_type == AGS_TYPE_INPUT){
+      channel = ags_channel_nth(machine->audio->input,
+				line);
+
+      play_port = ags_channel_find_port_by_specifier_and_scope(channel,
+							       specifier, TRUE);
+
+      recall_port = ags_channel_find_port_by_specifier_and_scope(channel,
+								 specifier, FALSE);
+    }else{
+      play_port = ags_audio_find_port_by_specifier_and_scope(machine->audio,
+							     specifier, TRUE);
+
+      recall_port = ags_audio_find_port_by_specifier_and_scope(machine->audio,
+							       specifier, FALSE);
+    }
+        
+    if(play_port != NULL){
+      match_count = 0;
+      tmp = x1 - x0;
+
+      if(x0 % (guint) AGS_AUTOMATION_DEFAULT_OFFSET != 0 &&
+	 x0 / (guint) AGS_AUTOMATION_DEFAULT_OFFSET != (x1 - AGS_AUTOMATION_DEFAULT_OFFSET) / (guint) AGS_AUTOMATION_DEFAULT_OFFSET){
+	match_count = 1;
+
+	tmp -= (x0 % (guint) AGS_AUTOMATION_DEFAULT_OFFSET);
+      }
+
+      match_count += (guint) ceil((gdouble) tmp / AGS_AUTOMATION_DEFAULT_OFFSET);
+    
+      success = FALSE;
+
+      timestamp->timer.ags_offset.offset = AGS_AUTOMATION_DEFAULT_OFFSET * floor(x0 / AGS_AUTOMATION_DEFAULT_OFFSET);
+
+      for(nth_match = 0; nth_match < match_count; nth_match++){
+	list_automation = play_port->automation;
+	list_automation = ags_automation_find_near_timestamp(list_automation, line,
+							     timestamp);
+
+	if(list_automation == NULL){
+	  current = ags_automation_new(machine->audio,
+				       line,
+				       channel_type, specifier);
+	  g_object_set(current,
+		       "port", play_port,
+		       NULL);
+
+	  current->timestamp->timer.ags_offset.offset = timestamp->timer.ags_offset.offset;
+
+	  ags_audio_add_automation(machine->audio,
+				   current);
+	  play_port->automation = ags_automation_add(play_port->automation,
+						     current);	  
+	}else{
+	  current = list_automation->data;
+	}
+
+	upper = current->upper;
+	lower = current->lower;
 	
-      range = upper - lower;
+	range = upper - lower;
 	
-      if(range == 0.0){
-	list_automation = list_automation->next;
-	g_warning("ags_ramp_acceleration_dialog.c - range = 0.0");
+	if(range == 0.0){
+	  g_warning("ags_ramp_acceleration_dialog.c - range = 0.0");
 	  
-	continue;
-      }
+	  break;
+	}
 	    
-      /* ramp value and move offset */
-      for(i = 0; i < step_count; i++){
-	acceleration = ags_acceleration_new();
-	acceleration->x = ((gdouble) x0 + (gdouble) ((gdouble) (x1 - x0) * (gdouble) ((gdouble) (i) / ((gdouble) step_count))));
-	acceleration->y = ((gdouble) y0 + ((gdouble) (y1 - y0) * (gdouble) ((gdouble) (i) / ((gdouble) step_count))));
+	/* ramp value and move offset */
+	if(!success){
+	  i = 0;
 
-#ifdef AGS_DEBUG
-	g_message("line %d - %d %f", line, acceleration->x, acceleration->y);
-#endif
+	  if(floor(x0 / (guint) AGS_AUTOMATION_DEFAULT_OFFSET) == floor(x1 / (guint) AGS_AUTOMATION_DEFAULT_OFFSET)){
+	    i_stop = step_count;
+
+	    tmp += (x1 - x0);
+	  }else{
+	    i_stop = tmp / (x1 - x0) * step_count;
+
+	    if(tmp + AGS_AUTOMATION_DEFAULT_OFFSET < x1 - x0){
+	      tmp += AGS_AUTOMATION_DEFAULT_OFFSET;
+	    }else{
+	      tmp = x1 - x0;
+	    }
+	  }
 	
-	ags_automation_add_acceleration(list_automation->data,
-					acceleration,
-					FALSE);
-      }
+	  success = TRUE;
+	}else{
+	  i_stop = (x1 - tmp) / (x1 - x0) * step_count;
+	
+	  if(tmp + AGS_AUTOMATION_DEFAULT_OFFSET < x1 - x0){
+	    tmp += AGS_AUTOMATION_DEFAULT_OFFSET;
+	  }else{
+	    tmp = x1 - x0;
+	  }
+	}
+	
+	for(; i < step_count && i < i_stop; i++){
+	  acceleration = ags_acceleration_new();
+	  acceleration->x = ((gdouble) x0 + (gdouble) ((gdouble) (x1 - x0) * (gdouble) ((gdouble) (i) / ((gdouble) step_count))));
+	  acceleration->y = ((gdouble) y0 + ((gdouble) (y1 - y0) * (gdouble) ((gdouble) (i + 1) / ((gdouble) step_count))));
 
-      /* iterate */
-      list_automation = list_automation->next;
+	  //#ifdef AGS_DEBUG
+	  g_message("line %d - %d %f", line, acceleration->x, acceleration->y);
+	  //#endif
+	
+	  ags_automation_add_acceleration(current,
+					  acceleration,
+					  FALSE);
+	
+	}
+	
+	timestamp->timer.ags_offset.offset += AGS_AUTOMATION_DEFAULT_OFFSET;
+      }
     }
 
+    if(recall_port != NULL){
+      match_count = 0;
+      tmp = x1 - x0;
+
+      if(x0 % (guint) AGS_AUTOMATION_DEFAULT_OFFSET != 0 &&
+	 x0 / (guint) AGS_AUTOMATION_DEFAULT_OFFSET != (x1 - AGS_AUTOMATION_DEFAULT_OFFSET) / (guint) AGS_AUTOMATION_DEFAULT_OFFSET){
+	match_count = 1;
+
+	tmp -= (x0 % (guint) AGS_AUTOMATION_DEFAULT_OFFSET);
+      }
+      
+      match_count += (guint) ceil((gdouble) tmp / AGS_AUTOMATION_DEFAULT_OFFSET);
+      
+      success = FALSE;
+
+      timestamp->timer.ags_offset.offset = AGS_AUTOMATION_DEFAULT_OFFSET * floor(x0 / AGS_AUTOMATION_DEFAULT_OFFSET);
+
+      for(nth_match = 0; nth_match < match_count; nth_match++){
+	list_automation = recall_port->automation;
+	list_automation = ags_automation_find_near_timestamp(list_automation, line,
+							     timestamp);
+
+	if(list_automation == NULL){
+	  current = ags_automation_new(machine->audio,
+				       line,
+				       channel_type, specifier);
+	  g_object_set(current,
+		       "port", recall_port,
+		       NULL);
+
+	  current->timestamp->timer.ags_offset.offset = timestamp->timer.ags_offset.offset;
+
+	  ags_audio_add_automation(machine->audio,
+				   current);
+	  recall_port->automation = ags_automation_add(recall_port->automation,
+						       current);	  
+	}else{
+	  current = list_automation->data;
+	}
+
+	upper = current->upper;
+	lower = current->lower;
+	
+	range = upper - lower;
+	
+	if(range == 0.0){
+	  g_warning("ags_ramp_acceleration_dialog.c - range = 0.0");
+	  
+	  break;
+	}
+	    
+	/* ramp value and move offset */
+	if(!success){
+	  i = 0;
+
+	  if(floor(x0 / (guint) AGS_AUTOMATION_DEFAULT_OFFSET) == floor(x1 / (guint) AGS_AUTOMATION_DEFAULT_OFFSET)){
+	    i_stop = step_count;
+
+	    tmp += (x1 - x0);
+	  }else{
+	    i_stop = tmp / (x1 - x0) * step_count;
+
+	    if(tmp + AGS_AUTOMATION_DEFAULT_OFFSET < x1 - x0){
+	      tmp += AGS_AUTOMATION_DEFAULT_OFFSET;
+	    }else{
+	      tmp = x1 - x0;
+	    }
+	  }
+	
+	  success = TRUE;
+	}else{
+	  i_stop = (x1 - tmp) / (x1 - x0) * step_count;
+	
+	  if(tmp + AGS_AUTOMATION_DEFAULT_OFFSET < x1 - x0){
+	    tmp += AGS_AUTOMATION_DEFAULT_OFFSET;
+	  }else{
+	    tmp = x1 - x0;
+	  }
+	}
+	
+	for(; i < step_count && i < i_stop; i++){
+	  acceleration = ags_acceleration_new();
+	  acceleration->x = ((gdouble) x0 + (gdouble) ((gdouble) (x1 - x0) * (gdouble) ((gdouble) (i) / ((gdouble) step_count))));
+	  acceleration->y = ((gdouble) y0 + ((gdouble) (y1 - y0) * (gdouble) ((gdouble) (i + 1) / ((gdouble) step_count))));
+
+	  //#ifdef AGS_DEBUG
+	  g_message("line %d - %d %f", line, acceleration->x, acceleration->y);
+	  //#endif
+	
+	  ags_automation_add_acceleration(current,
+					  acceleration,
+					  FALSE);
+	
+	}
+
+	timestamp->timer.ags_offset.offset += AGS_AUTOMATION_DEFAULT_OFFSET;
+      }
+    }
+
+    if(notebook == NULL){
+      break;
+    }
+    
     line++;
   }
 }
