@@ -130,7 +130,7 @@ ags_machine_collection_entry_class_init(AgsMachineCollectionEntryClass *machine_
    *
    * The assigned #AgsMachine.
    * 
-   * Since: 0.8.0
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_object("machine",
 				   i18n_pspec("assigned machine"),
@@ -264,13 +264,13 @@ ags_machine_collection_entry_set_property(GObject *gobject,
 	gtk_label_set_text(machine_collection_entry->label,
 			   g_strdup_printf("%s: %s",
 					   G_OBJECT_TYPE_NAME(machine),
-					   AGS_MACHINE(machine)->name));
+					   AGS_MACHINE(machine)->machine_name));
 	
 	//	gtk_entry_set_text(machine_collection_entry->instrument,
 	//		   G_OBJECT_TYPE_NAME(machine));
 
       	gtk_entry_set_text(machine_collection_entry->sequence,
-			   AGS_MACHINE(machine)->name);
+			   AGS_MACHINE(machine)->machine_name);
       }
 
       machine_collection_entry->machine = machine;
@@ -554,7 +554,7 @@ ags_machine_collection_entry_reset(AgsApplicable *applicable)
  *
  * Returns: a new #AgsMachineCollectionEntry
  *
- * Since: 0.8.0
+ * Since: 1.0.0
  */
 AgsMachineCollectionEntry*
 ags_machine_collection_entry_new()
