@@ -20,23 +20,9 @@
 #include <ags/X/import/ags_track_collection_mapper.h>
 #include <ags/X/import/ags_track_collection_mapper_callbacks.h>
 
-#include <ags/lib/ags_complex.h>
-
-#include <ags/object/ags_application_context.h>
-#include <ags/object/ags_connectable.h>
-#include <ags/object/ags_applicable.h>
-#include <ags/object/ags_soundcard.h>
-
-#ifdef AGS_USE_LINUX_THREADS
-#include <ags/thread/ags_thread-kthreads.h>
-#else
-#include <ags/thread/ags_thread-posix.h>
-#endif 
-
-#include <ags/audio/ags_output.h>
-#include <ags/audio/ags_input.h>
-
-#include <ags/audio/task/ags_add_audio.h>
+#include <ags/libags.h>
+#include <ags/libags-audio.h>
+#include <ags/libags-gui.h>
 
 #include <ags/X/ags_window.h>
 #include <ags/X/ags_machine.h>
@@ -46,7 +32,7 @@
 #include <ags/X/import/ags_midi_import_wizard.h>
 #include <ags/X/import/ags_track_collection.h>
 
-#include <ags/X/editor/ags_note_edit.h>
+#include <ags/X/editor/ags_notation_edit.h>
 
 #include <ags/X/machine/ags_drum.h>
 #include <ags/X/machine/ags_matrix.h>
@@ -291,7 +277,7 @@ ags_track_collection_mapper_init(AgsTrackCollectionMapper *track_collection_mapp
 		   0, 0);
 
   /* offset */
-  track_collection_mapper->offset = (GtkSpinButton *) gtk_spin_button_new_with_range(0.0, 256.0 * (gdouble) AGS_NOTE_EDIT_MAX_CONTROLS, 1.0);
+  track_collection_mapper->offset = (GtkSpinButton *) gtk_spin_button_new_with_range(0.0, (gdouble) AGS_NOTATION_EDITOR_MAX_CONTROLS, 1.0);
   gtk_table_attach((GtkTable *) track_collection_mapper,
 		   (GtkWidget *) track_collection_mapper->offset,
 		   3, 4,
@@ -510,6 +496,10 @@ ags_track_collection_mapper_apply(AgsApplicable *applicable)
     g_warning("unknown machine type");
   }
 
+  /* connect everything */
+  ags_connectable_connect(AGS_CONNECTABLE(machine));
+
+  /* set size */
   ags_audio_set_audio_channels(machine->audio,
 			       gtk_spin_button_get_value_as_int(track_collection_mapper->audio_channels));
   ags_audio_set_pads(machine->audio,
@@ -543,9 +533,6 @@ ags_track_collection_mapper_apply(AgsApplicable *applicable)
 		     GTK_WIDGET(machine),
 		     FALSE, FALSE, 0);
 
-  /* connect everything */
-  ags_connectable_connect(AGS_CONNECTABLE(machine));
-
   /* */
   gtk_widget_show_all(GTK_WIDGET(machine));
 }
