@@ -46,6 +46,17 @@ struct _AgsAudiorec
 
   gchar *name;
   gchar *xml_type;
+
+  GtkEntry *filename;
+  GtkButton *open;
+
+  GtkRadioButton *keep_data;
+  GtkRadioButton *mix_data;
+  GtkRadioButton *replace_data;
+
+  GtkVBox *hindicator_vbox;
+
+  GtkFileChooserDialog *open_dialog;
 };
 
 struct _AgsAudiorecClass
@@ -55,6 +66,9 @@ struct _AgsAudiorecClass
 
 GType ags_audiorec_get_type(void);
 
+void ags_audiorec_open_filename(AgsAudiorec *audiorec,
+				gchar *filename);
+
 AgsAudiorec* ags_audiorec_new(GObject *soundcard);
 
 #endif /*__AGS_AUDIOREC_H__*/
