@@ -35,6 +35,7 @@ ags_drum_output_line_resize_pads_callback(AgsDrum *drum, GType channel_type,
 
   gchar *str;
 
+  gboolean rt_safe;
   gboolean performance_mode;
 
   audio = AGS_MACHINE(drum)->audio;
@@ -44,14 +45,38 @@ ags_drum_output_line_resize_pads_callback(AgsDrum *drum, GType channel_type,
   str = ags_config_get_value(config,
 			     AGS_CONFIG_GENERIC,
 			     "engine-mode");
-  performance_mode = FALSE;
+
+  rt_safe = TRUE;
+  performance_mode = TRUE;
+
+  str = ags_config_get_value(config,
+			     AGS_CONFIG_GENERIC,
+			     "rt-safe");
+
+  if(str != NULL &&
+     !g_ascii_strncasecmp(str,
+			  "FALSE",
+			  6)){
+    rt_safe = FALSE;
+  }
+
+  str = ags_config_get_value(config,
+			     AGS_CONFIG_GENERIC,
+			     "engine-mode");
+
+  if(str != NULL &&
+     !g_ascii_strncasecmp(str,
+			  "performance",
+			  12)){
+    performance_mode = TRUE;
+  }else{
+    performance_mode = FALSE;
+  }
 
   if(channel_type == AGS_TYPE_INPUT){
     if(pads_new > pads_old){
-      if(str != NULL &&
-	 !g_ascii_strncasecmp(str,
-			      "performance",
-			      12)){
+      if(rt_safe ||
+	 performance_mode){
 	/* ags-copy */
 	ags_recall_factory_create(audio,
 				  NULL, NULL,
