@@ -336,6 +336,9 @@ ags_live_lv2_bridge_init(AgsLiveLv2Bridge *live_lv2_bridge)
 
   AgsAudio *audio;
 
+  g_signal_connect_after((GObject *) live_lv2_bridge, "parent-set",
+			 G_CALLBACK(ags_live_lv2_bridge_parent_set_callback), (gpointer) live_lv2_bridge);
+
   if(ags_live_lv2_bridge_lv2ui_handle == NULL){
     ags_live_lv2_bridge_lv2ui_handle = g_hash_table_new_full(g_direct_hash, g_direct_equal,
 							   NULL,
