@@ -1537,6 +1537,7 @@ ags_lv2_bridge_input_map_recall(AgsLv2Bridge *lv2_bridge,
 
   guint input_pads;
   guint audio_channels;
+  gboolean rt_safe;
   gboolean performance_mode;
 
   pthread_mutex_t *application_mutex;
@@ -1638,15 +1639,35 @@ ags_lv2_bridge_input_map_recall(AgsLv2Bridge *lv2_bridge,
     }
 
     /* map dependending on output */
+    rt_safe = TRUE;
+    performance_mode = TRUE;
+
+    str = ags_config_get_value(config,
+			       AGS_CONFIG_GENERIC,
+			       "rt-safe");
+
+    if(str != NULL &&
+       !g_ascii_strncasecmp(str,
+			    "FALSE",
+			    6)){
+      rt_safe = FALSE;
+    }
+
     str = ags_config_get_value(config,
 			       AGS_CONFIG_GENERIC,
 			       "engine-mode");
-    performance_mode = FALSE;
-  
+
     if(str != NULL &&
        !g_ascii_strncasecmp(str,
 			    "performance",
 			    12)){
+      performance_mode = TRUE;
+    }else{
+      performance_mode = FALSE;
+    }
+    
+    if(rt_safe ||
+       performance_mode){
       /* ags-copy */
       ags_recall_factory_create(audio,
 				NULL, NULL,
@@ -1686,16 +1707,29 @@ ags_lv2_bridge_input_map_recall(AgsLv2Bridge *lv2_bridge,
 			       AGS_RECALL_FACTORY_ADD),
 			      0);
     /* ags-stream */
-    ags_recall_factory_create(audio,
-			      NULL, NULL,
-			      "ags-stream",
-			      audio_channel_start, audio_channels, 
-			      input_pad_start, input_pads,
-			      (AGS_RECALL_FACTORY_INPUT |
-			       AGS_RECALL_FACTORY_PLAY |
-			       AGS_RECALL_FACTORY_RECALL | 
-			       AGS_RECALL_FACTORY_ADD),
-			      0);
+    if(!rt_safe){
+      ags_recall_factory_create(audio,
+				NULL, NULL,
+				"ags-stream",
+				audio_channel_start, audio_channels, 
+				input_pad_start, input_pads,
+				(AGS_RECALL_FACTORY_INPUT |
+				 AGS_RECALL_FACTORY_PLAY |
+				 AGS_RECALL_FACTORY_RECALL | 
+				 AGS_RECALL_FACTORY_ADD),
+				0);
+    }else{
+      ags_recall_factory_create(audio,
+				NULL, NULL,
+				"ags-rt-stream",
+				audio_channel_start, audio_channels, 
+				input_pad_start, input_pads,
+				(AGS_RECALL_FACTORY_INPUT |
+				 AGS_RECALL_FACTORY_PLAY |
+				 AGS_RECALL_FACTORY_RECALL | 
+				 AGS_RECALL_FACTORY_ADD),
+				0);
+    }      
   }
   
   lv2_bridge->mapped_input_pad = input_pads;
@@ -1722,6 +1756,7 @@ ags_lv2_bridge_output_map_recall(AgsLv2Bridge *lv2_bridge,
 
   guint output_pads, input_pads;
   guint audio_channels;
+  gboolean rt_safe;
   gboolean performance_mode;
 
   pthread_mutex_t *application_mutex;
@@ -1758,16 +1793,36 @@ ags_lv2_bridge_output_map_recall(AgsLv2Bridge *lv2_bridge,
 
   if((AGS_MACHINE_IS_SYNTHESIZER & (AGS_MACHINE(lv2_bridge)->flags)) != 0){
     /* map dependending on output */
+    rt_safe = TRUE;
+    performance_mode = TRUE;
+
+    str = ags_config_get_value(config,
+			       AGS_CONFIG_GENERIC,
+			       "rt-safe");
+
+    if(str != NULL &&
+       !g_ascii_strncasecmp(str,
+			    "FALSE",
+			    6)){
+      rt_safe = FALSE;
+    }
+
     str = ags_config_get_value(config,
 			       AGS_CONFIG_GENERIC,
 			       "engine-mode");
-    performance_mode = FALSE;
-  
-    /* remap for input */
+
     if(str != NULL &&
        !g_ascii_strncasecmp(str,
 			    "performance",
 			    12)){
+      performance_mode = TRUE;
+    }else{
+      performance_mode = FALSE;
+    }
+  
+    /* remap for input */
+    if(rt_safe ||
+       performance_mode){
       /* ags-copy */
       ags_recall_factory_create(audio,
 				NULL, NULL,
