@@ -26,13 +26,23 @@ ags_panel_parent_set_callback(GtkWidget *widget, GtkObject *old_parent, AgsPanel
 {
   AgsWindow *window;
 
-  if(old_parent != NULL)
+  gchar *str;
+
+  if(old_parent != NULL){
     return;
+  }
 
   window = AGS_WINDOW(gtk_widget_get_toplevel(widget));
 
-  AGS_MACHINE(panel)->name = g_strdup_printf("Default %d",
-					     ags_window_find_machine_counter(window, AGS_TYPE_PANEL)->counter);
+  str = g_strdup_printf("Default %d",
+			ags_window_find_machine_counter(window, AGS_TYPE_PANEL)->counter);
+
+  g_object_set(AGS_MACHINE(panel),
+	       "machine-name", str,
+	       NULL);
+
   ags_window_increment_machine_counter(window,
 				       AGS_TYPE_PANEL);
+
+  g_free(str);
 }
