@@ -34,6 +34,9 @@
 #define AGS_IS_SYNTH_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE((class), AGS_TYPE_SYNTH))
 #define AGS_SYNTH_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS((obj), AGS_TYPE_SYNTH, AgsSynthClass))
 
+#define AGS_SYNTH_BASE_NOTE_MAX (72.0)
+#define AGS_SYNTH_BASE_NOTE_MIN (-72.0)
+
 typedef struct _AgsSynth AgsSynth;
 typedef struct _AgsSynthClass AgsSynthClass;
 
