@@ -26,6 +26,8 @@
 #include <ags/libags.h>
 #include <ags/libags-audio.h>
 
+#include <ags/X/ags_window.h>
+
 #include <ags/X/file/ags_simple_file.h>
 
 #include <unistd.h>
@@ -63,6 +65,8 @@ struct _AgsGuiThread
   GCond cond;
   
   GMainContext *main_context;
+
+  GThread *gtk_thread;
   
   gint cached_poll_array_size;
   GPollFD *cached_poll_array;
