@@ -19,7 +19,7 @@
 
 #include <ags/audio/ags_acceleration.h>
 
-#include <ags/object/ags_connectable.h>
+#include <ags/libags.h>
 
 #include <stdlib.h>
 
@@ -100,6 +100,7 @@ void
 ags_acceleration_class_init(AgsAccelerationClass *acceleration)
 {
   GObjectClass *gobject;
+
   GParamSpec *param_spec;
   
   ags_acceleration_parent_class = g_type_class_peek_parent(acceleration);
