@@ -32,17 +32,11 @@
 #else
 #include <ags/thread/ags_thread-posix.h>
 #endif
-#include <ags/thread/ags_single_thread.h>
-#include <ags/thread/ags_autosave_thread.h>
-#include <ags/thread/ags_task_thread.h>
+
 #include <ags/thread/ags_thread_pool.h>
 
 #include <ags/server/ags_server.h>
 
-#include <ags/audio/thread/ags_audio_loop.h>
-#include <ags/audio/thread/ags_soundcard_thread.h>
-#include <ags/audio/thread/ags_export_thread.h>
-
 #define AGS_TYPE_AUDIO_APPLICATION_CONTEXT                (ags_audio_application_context_get_type())
 #define AGS_AUDIO_APPLICATION_CONTEXT(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_AUDIO_APPLICATION_CONTEXT, AgsAudioApplicationContext))
 #define AGS_AUDIO_APPLICATION_CONTEXT_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST(class, AGS_TYPE_AUDIO_APPLICATION_CONTEXT, AgsAudioApplicationContextClass))
@@ -52,14 +46,21 @@
 
 #define AGS_AUDIO_RT_PRIORITY (49)
 
-#define AGS_AUDIO_DEFAULT_VERSION "0.7.122.8\0"
-#define AGS_AUDIO_BUILD_ID "Tue Mar 21 20:03:29 CET 2017\0"
+#define AGS_AUDIO_DEFAULT_VERSION "0.7.122.8"
+#define AGS_AUDIO_BUILD_ID "Tue Mar 21 20:03:29 CET 2017"
 
-#define AGS_EFFECTS_DEFAULT_VERSION "0.7.13\0"
+#define AGS_EFFECTS_DEFAULT_VERSION "0.7.13"
 
 typedef struct _AgsAudioApplicationContext AgsAudioApplicationContext;
 typedef struct _AgsAudioApplicationContextClass AgsAudioApplicationContextClass;
 
+/**
+ * AgsAudioApplicationContextFlags:
+ * @AGS_AUDIO_APPLICATION_CONTEXT_USE_ALSA: use alsa backend
+ * 
+ * Enum values to control the behavior or indicate internal state of #AgsAudioApplicationContextFlags by
+ * enable/disable as flags.
+ */
 typedef enum{
   AGS_AUDIO_APPLICATION_CONTEXT_USE_ALSA      = 1,
 }AgsAudioApplicationContextFlags;
