@@ -24,7 +24,7 @@
 #include <glib-object.h>
 #include <libxml/tree.h>
 
-#include <ags/lib/ags_function.h>
+#include <ags/libags.h>
 
 #include <ags/audio/ags_acceleration.h>
 
@@ -39,14 +39,21 @@
 
 #define AGS_AUTOMATION_TICS_PER_BEAT (1.0)
 #define AGS_AUTOMATION_MINIMUM_ACCELERATION_LENGTH (1.0 / 16.0 / 64.0)
+#define AGS_AUTOMATION_MAXIMUM_ACCELERATION_LENGTH (16.0)
 
 #define AGS_AUTOMATION_DEFAULT_LENGTH (64 * 16 * 1200 / AGS_AUTOMATION_TICS_PER_BEAT)
 #define AGS_AUTOMATION_DEFAULT_JIFFIE (60.0 / AGS_AUTOMATION_DEFAULT_BPM / AGS_AUTOMATION_TICS_PER_BEAT)
 #define AGS_AUTOMATION_DEFAULT_DURATION (AGS_AUTOMATION_DEFAULT_LENGTH * AGS_AUTOMATION_DEFAULT_JIFFIE * AGS_MICROSECONDS_PER_SECOND)
+#define AGS_AUTOMATION_DEFAULT_OFFSET (64 * (1 / AGS_AUTOMATION_MINIMUM_ACCELERATION_LENGTH))
 
 #define AGS_AUTOMATION_DEFAULT_PRECISION (8)
 #define AGS_AUTOMATION_MAXIMUM_STEPS (128)
 
+#define AGS_AUTOMATION_CLIPBOARD_VERSION "1.3.0"
+#define AGS_AUTOMATION_CLIPBOARD_TYPE "AgsAutomationClipboardXml"
+#define AGS_AUTOMATION_CLIPBOARD_FORMAT "AgsAutomationNativeScale"
+#define AGS_AUTOMATION_CLIPBOARD_LEGACY_FORMAT "AgsAutomationNativePiano"
+
 typedef struct _AgsAutomation AgsAutomation;
 typedef struct _AgsAutomationClass AgsAutomationClass;
 
@@ -69,7 +76,7 @@ struct _AgsAutomation
 
   guint flags;
 
-  GObject *timestamp;
+  AgsTimestamp *timestamp;
 
   GObject *audio;
   guint line;
@@ -108,7 +115,13 @@ GList* ags_automation_find_port(GList *automation,
 				GObject *port);
 
 GList* ags_automation_find_near_timestamp(GList *automation, guint line,
-					  GObject *timestamp);
+					  AgsTimestamp *timestamp);
+GList* ags_automation_find_near_timestamp_extended(GList *automation, guint line,
+						   GType channel_type, gchar *control_name,
+						   AgsTimestamp *timestamp);
+
+GList* ags_automation_add(GList *automation,
+			  AgsAutomation *new_automation);
 
 void ags_automation_add_acceleration(AgsAutomation *automation,
 				     AgsAcceleration *acceleration,
@@ -153,15 +166,25 @@ void ags_automation_merge_clipboard(xmlNode *audio_node,
 				    xmlNode *automation_node);
 
 void ags_automation_insert_from_clipboard(AgsAutomation *automation,
-					  xmlNodePtr content,
+					  xmlNode *automation_node,
 					  gboolean reset_x_offset, guint x_offset,
 					  gboolean reset_y_offset, gdouble y_offset);
 
+void ags_automation_insert_from_clipboard_extended(AgsAutomation *automation,
+						   xmlNode *automation_node,
+						   gboolean reset_x_offset, guint x_offset,
+						   gboolean reset_y_offset, gdouble y_offset,
+						   gboolean match_line, gboolean no_duplicates);
+
 GList* ags_automation_get_current(AgsAutomation *automation);
 
 gchar** ags_automation_get_specifier_unique(GList *automation);
+gchar** ags_automation_get_specifier_unique_with_channel_type(GList *automation,
+							      GType channel_type);
 GList* ags_automation_find_specifier(GList *automation,
 				     gchar *specifier);
+GList* ags_automation_find_channel_type_with_control_name(GList *automation,
+							  GType channel_type, gchar *specifier);
 GList* ags_automation_find_specifier_with_type_and_line(GList *automation,
 							gchar *specifier,
 							GType channel_type,
