@@ -326,9 +326,12 @@ ags_note_init(AgsNote *note)
   note->flags = 0;
 
   note->x[0] = 0;
-  note->x[1] = 0;
+  note->x[1] = 1;
   note->y = 0;
 
+  note->rt_offset = 0;
+  note->rt_attack = 0;
+  
   note->stream_delay = 0.0;
   note->stream_attack = 0;
 
@@ -1215,7 +1218,12 @@ ags_note_new()
 }
 
 /**
- * ags_note_new:
+ * ags_note_new_with_offset:
+ * @x0: x0
+ * @x1: x1
+ * @y: y
+ * @stream_delay: delay
+ * @stream_attack: attack
  *
  * Creates an #AgsNote
  *
