@@ -75,6 +75,9 @@ struct _AgsNote
   guint x[2];
   guint y;
 
+  guint64 rt_offset;
+  guint rt_attack;
+  
   gdouble stream_delay;
   gdouble stream_attack;
   
