@@ -37,18 +37,19 @@ typedef struct _AgsRecallID AgsRecallID;
 typedef struct _AgsRecallIDClass AgsRecallIDClass;
 
 typedef enum{
-  AGS_RECALL_ID_PLAYBACK          = 1,
-  AGS_RECALL_ID_SEQUENCER         = 1 << 1,
-  AGS_RECALL_ID_NOTATION          = 1 << 2,
-  AGS_RECALL_ID_DUPLICATE         = 1 << 3,
-  AGS_RECALL_ID_RESOLVE           = 1 << 4,
-  AGS_RECALL_ID_INIT_PRE          = 1 << 5,
-  AGS_RECALL_ID_INIT_INTER        = 1 << 6,
-  AGS_RECALL_ID_INIT_POST         = 1 << 7,
-  AGS_RECALL_ID_PRE               = 1 << 8,
-  AGS_RECALL_ID_INTER             = 1 << 9,
-  AGS_RECALL_ID_POST              = 1 << 10,
-  AGS_RECALL_ID_CANCEL            = 1 << 11,
+  AGS_RECALL_ID_CONNECTED         = 1,
+  AGS_RECALL_ID_PLAYBACK          = 1 <<  1,
+  AGS_RECALL_ID_SEQUENCER         = 1 <<  2,
+  AGS_RECALL_ID_NOTATION          = 1 <<  3,
+  AGS_RECALL_ID_DUPLICATE         = 1 <<  4,
+  AGS_RECALL_ID_RESOLVE           = 1 <<  5,
+  AGS_RECALL_ID_INIT_PRE          = 1 <<  6,
+  AGS_RECALL_ID_INIT_INTER        = 1 <<  7,
+  AGS_RECALL_ID_INIT_POST         = 1 <<  8,
+  AGS_RECALL_ID_PRE               = 1 <<  9,
+  AGS_RECALL_ID_INTER             = 1 << 10,
+  AGS_RECALL_ID_POST              = 1 << 11,
+  AGS_RECALL_ID_CANCEL            = 1 << 12,
 }AgsRecallIDFlags;
 
 struct _AgsRecallID
@@ -74,6 +75,7 @@ void ags_recall_id_unset_run_stage(AgsRecallID *recall_id, gint stage);
 
 AgsRecallID* ags_recall_id_find_recycling_context(GList *recall_id_list,
 						  AgsRecyclingContext *recycling_context);
+
 AgsRecallID* ags_recall_id_find_parent_recycling_context(GList *recall_id_list,
 							 AgsRecyclingContext *parent_recycling_context);
 
