@@ -151,7 +151,7 @@ ags_audio_file_link_class_init(AgsAudioFileLinkClass *audio_file_link)
    *
    * The assigned preset.
    * 
-   * Since: 0.7.45
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_string("preset",
 				   i18n_pspec("the preset"),
@@ -167,7 +167,7 @@ ags_audio_file_link_class_init(AgsAudioFileLinkClass *audio_file_link)
    *
    * The assigned instrument.
    * 
-   * Since: 0.7.45
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_string("instrument",
 				   i18n_pspec("the instrument"),
@@ -183,7 +183,7 @@ ags_audio_file_link_class_init(AgsAudioFileLinkClass *audio_file_link)
    *
    * The assigned sample.
    * 
-   * Since: 0.7.45
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_string("sample",
 				   i18n_pspec("the sample"),
@@ -199,7 +199,7 @@ ags_audio_file_link_class_init(AgsAudioFileLinkClass *audio_file_link)
    *
    * The assigned audio channel.
    * 
-   * Since: 0.4.2
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_uint("audio-channel",
 				 i18n_pspec("audio channel to read"),
@@ -216,7 +216,7 @@ ags_audio_file_link_class_init(AgsAudioFileLinkClass *audio_file_link)
    *
    * The assigned timestamp.
    * 
-   * Since: 0.4.2
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_object("timestamp",
 				   i18n_pspec("timestamp"),
@@ -463,6 +463,8 @@ ags_audio_file_link_write(AgsFile *file,
 			     node,
 			     audio_file_link->timestamp);
   }
+
+  return(node);
 }
 
 void
@@ -658,7 +660,7 @@ ags_audio_file_link_read_launch(AgsFileLaunch *file_launch,
  *
  * Returns: a new #AgsAudioFileLink
  *
- * Since: 0.4
+ * Since: 1.0.0
  */
 AgsAudioFileLink*
 ags_audio_file_link_new()
