@@ -19,7 +19,7 @@
 
 #include <ags/audio/file/ags_ipatch_sf2_reader.h>
 
-#include <ags/object/ags_connectable.h>
+#include <ags/libags.h>
 
 #include <stdlib.h>
 
