@@ -19,7 +19,18 @@
 
 #include <ags/audio/pulse/ags_pulse_client.h>
 
-#include <ags/libags.h>
+#include <ags/util/ags_id_generator.h>
+
+#include <ags/object/ags_application_context.h>
+#include <ags/object/ags_distributed_manager.h>
+#include <ags/object/ags_main_loop.h>
+#include <ags/object/ags_connectable.h>
+#include <ags/object/ags_distributed_manager.h>
+#include <ags/object/ags_soundcard.h>
+#include <ags/object/ags_sequencer.h>
+
+#include <ags/thread/ags_mutex_manager.h>
+#include <ags/thread/ags_task_thread.h>
 
 #include <ags/audio/ags_sound_provider.h>
 #include <ags/audio/ags_channel.h>
@@ -655,7 +666,6 @@ ags_pulse_client_open(AgsPulseClient *pulse_client,
     pa_context_set_state_callback(pulse_client->context,
 				  ags_pulse_client_state_callback,
 				  pulse_client);
-#if 0
     ready = FALSE;
     
     while(!ready){
@@ -671,7 +681,6 @@ ags_pulse_client_open(AgsPulseClient *pulse_client,
 			    NULL);
       }
     }
-#endif
 #endif
   }
 }
