@@ -19,7 +19,18 @@
 
 #include <ags/audio/pulse/ags_pulse_port.h>
 
-#include <ags/libags.h>
+#include <ags/util/ags_id_generator.h>
+
+#include <ags/object/ags_application_context.h>
+#include <ags/object/ags_distributed_manager.h>
+#include <ags/object/ags_connectable.h>
+#include <ags/object/ags_distributed_manager.h>
+#include <ags/object/ags_soundcard.h>
+#include <ags/object/ags_sequencer.h>
+
+#include <ags/thread/ags_mutex_manager.h>
+#include <ags/thread/ags_task_thread.h>
+#include <ags/thread/ags_polling_thread.h>
 
 #include <ags/audio/ags_sound_provider.h>
 #include <ags/audio/ags_audio_signal.h>
@@ -930,7 +941,7 @@ ags_pulse_port_stream_request_callback(pa_stream *stream, size_t length, AgsPuls
   }
 
   g_atomic_int_and(&(AGS_THREAD(audio_loop)->flags),
- 		   (~(AGS_THREAD_TIMING)));
+		   (~(AGS_THREAD_TIMING)));
 
   /*  */
   pthread_mutex_lock(mutex);
