@@ -195,6 +195,8 @@ ags_copy_pattern_channel_run_init(AgsCopyPatternChannelRun *copy_pattern_channel
   AGS_RECALL(copy_pattern_channel_run)->port = NULL;
 
   AGS_RECALL(copy_pattern_channel_run)->child_type = G_TYPE_NONE;
+
+  copy_pattern_channel_run->note = NULL;
 }
 
 void
@@ -291,19 +293,87 @@ ags_copy_pattern_channel_run_resolve_dependencies(AgsRecall *recall)
 void
 ags_copy_pattern_channel_run_run_init_pre(AgsRecall *recall)
 {
-  AgsCopyPatternAudioRun *copy_pattern_audio_run;
+  AgsChannel *source;
+  AgsPattern *pattern;
+  AgsNote *note;
+  
+  AgsCopyPatternChannel *copy_pattern_channel;
   AgsCopyPatternChannelRun *copy_pattern_channel_run;
 
+  AgsMutexManager *mutex_manager;
+
+  guint pad;
+  guint i, i_stop;
+  
+  GValue pattern_value = { 0, };  
+
+  pthread_mutex_t *application_mutex;
+  pthread_mutex_t *source_mutex;  
+  pthread_mutex_t *pattern_mutex;
+  
+  mutex_manager = ags_mutex_manager_get_instance();
+  application_mutex = ags_mutex_manager_get_application_mutex(mutex_manager);
+
   AGS_RECALL_CLASS(ags_copy_pattern_channel_run_parent_class)->run_init_pre(recall);
 
+  /*  */
   copy_pattern_channel_run = AGS_COPY_PATTERN_CHANNEL_RUN(recall);
 
-  /* get AgsCopyPatternAudioRun */
-  copy_pattern_audio_run = AGS_COPY_PATTERN_AUDIO_RUN(AGS_RECALL_CHANNEL_RUN(copy_pattern_channel_run)->recall_audio_run);
+  /* get AgsCopyPatternChannel */
+  copy_pattern_channel = AGS_COPY_PATTERN_CHANNEL(copy_pattern_channel_run->recall_channel_run.recall_channel);
 
-  /* notify dependency */
-  ags_recall_notify_dependency(AGS_RECALL(copy_pattern_audio_run->count_beats_audio_run),
- 			       AGS_RECALL_NOTIFY_CHANNEL_RUN, 1);
+  /* get source */
+  source = AGS_RECALL_CHANNEL(copy_pattern_channel)->source;
+
+  pthread_mutex_lock(application_mutex);
+  
+  source_mutex = ags_mutex_manager_lookup(mutex_manager,
+					  (GObject *) source);
+    
+  pthread_mutex_unlock(application_mutex);
+
+  /* get AgsPattern */
+  g_value_init(&pattern_value, G_TYPE_POINTER);
+  ags_port_safe_read(copy_pattern_channel->pattern,
+		     &pattern_value);
+
+  pattern = g_value_get_pointer(&pattern_value);
+
+  pthread_mutex_lock(application_mutex);
+  
+  pattern_mutex = ags_mutex_manager_lookup(mutex_manager,
+					   (GObject *) pattern);
+  
+  pthread_mutex_unlock(application_mutex);
+
+  /* add note */
+  pthread_mutex_lock(source_mutex);
+  
+  pad = source->pad;
+
+  pthread_mutex_unlock(source_mutex);
+
+  /* i stop */
+  pthread_mutex_lock(pattern_mutex);
+
+  i_stop = pattern->dim[2];
+
+  pthread_mutex_unlock(pattern_mutex);
+  
+  for(i = 0; i < i_stop; i++){
+    note = ags_note_new();
+
+    note->x[0] = i;
+    note->x[1] = i + 1;
+
+    note->y = pad;
+
+    copy_pattern_channel_run->note = g_list_prepend(copy_pattern_channel_run->note,
+						    note);
+    g_object_ref(note);
+  }
+
+  copy_pattern_channel_run->note = g_list_reverse(copy_pattern_channel_run->note);
 }
 
 void
@@ -321,6 +391,11 @@ ags_copy_pattern_channel_run_done(AgsRecall *recall)
   ags_recall_notify_dependency(AGS_RECALL(copy_pattern_audio_run->count_beats_audio_run),
  			       AGS_RECALL_NOTIFY_CHANNEL_RUN, -1);
 
+  g_list_free_full(copy_pattern_channel_run->note,
+		   g_object_unref);
+
+  copy_pattern_channel_run->note = NULL;
+  
   /* call parent */
   AGS_RECALL_CLASS(ags_copy_pattern_channel_run_parent_class)->done(recall);
 }
@@ -536,18 +611,12 @@ ags_copy_pattern_channel_run_sequencer_alloc_callback(AgsDelayAudioRun *delay_au
       
       while(recycling != end_recycling){
 	child_recall_id = AGS_RECALL(copy_pattern_channel_run)->recall_id;
-	
-	/* create audio signal */
-	audio_signal = ags_audio_signal_new(AGS_RECALL(copy_pattern_audio)->soundcard,
-					    (GObject *) recycling,
-					    (GObject *) child_recall_id);
-	ags_recycling_create_audio_signal_with_defaults(recycling,
-							audio_signal,
-							0.0, attack);
-	audio_signal->flags &= (~AGS_AUDIO_SIGNAL_TEMPLATE);
-	audio_signal->stream_current = audio_signal->stream_beginning;
 
 	/* apply preset */
+	note = g_list_nth(copy_pattern_channel_run->note,
+			  sequencer_counter)->data;	
+	note->rt_attack = attack;
+	
 	if(preset != NULL){
 	  AgsComplex *val;
 	  
@@ -555,16 +624,7 @@ ags_copy_pattern_channel_run_sequencer_alloc_callback(AgsDelayAudioRun *delay_au
 
 	  GError *error;
 	  
-	  note = ags_note_new();
-
 	  note->flags |= AGS_NOTE_ENVELOPE;
-
-	  note->x[0] = sequencer_counter;
-	  note->x[1] = sequencer_counter + 1;
-
-	  note->y = pad;
-
-	  audio_signal->note = note;
 	  
 	  /* get attack */
 	  g_value_init(&value,
@@ -643,8 +703,44 @@ ags_copy_pattern_channel_run_sequencer_alloc_callback(AgsDelayAudioRun *delay_au
 	  }
 	}
 	
-	ags_connectable_connect(AGS_CONNECTABLE(audio_signal));
-	
+	if(!AGS_RECALL(copy_pattern_audio)->rt_safe){
+	  /* create audio signal */
+	  audio_signal = ags_audio_signal_new(AGS_RECALL(copy_pattern_audio)->soundcard,
+					      (GObject *) recycling,
+					      (GObject *) child_recall_id);
+	  ags_recycling_create_audio_signal_with_defaults(recycling,
+							  audio_signal,
+							  0.0, attack);
+	  audio_signal->flags &= (~AGS_AUDIO_SIGNAL_TEMPLATE);
+	  audio_signal->stream_current = audio_signal->stream_beginning;
+
+	  ags_connectable_connect(AGS_CONNECTABLE(audio_signal));
+
+	  audio_signal->recall_id = (GObject *) child_recall_id;
+	  ags_recycling_add_audio_signal(recycling,
+					 audio_signal);
+
+	  g_object_set(audio_signal,
+		       "note", note,
+		       NULL);
+	}else{
+	  GList *list;
+
+	  audio_signal = NULL;
+	  list = ags_audio_signal_get_by_recall_id(recycling->audio_signal,
+						   child_recall_id);
+	    
+	  if(list != NULL){
+	    audio_signal = list->data;
+
+	    g_object_set(audio_signal,
+			 "note", note,
+			 NULL);
+	  }
+	    
+	  note->rt_offset = 0;
+	}
+		
 	/*
 	 * emit add_audio_signal on AgsRecycling
 	 */
@@ -652,10 +748,6 @@ ags_copy_pattern_channel_run_sequencer_alloc_callback(AgsDelayAudioRun *delay_au
 	g_message("play %x", AGS_RECALL(copy_pattern_channel_run)->recall_id);
 #endif
 
-	audio_signal->recall_id = (GObject *) child_recall_id;
-	ags_recycling_add_audio_signal(recycling,
-				       audio_signal);
-
 	/*
 	 * unref AgsAudioSignal because AgsCopyPatternChannelRun has no need for it
 	 * if you need a valid reference to audio_signal you have to g_object_ref(audio_signal)
