@@ -20,11 +20,7 @@
 #include <ags/audio/recall/ags_envelope_audio_signal.h>
 #include <ags/audio/recall/ags_envelope_channel.h>
 
-#include <ags/lib/ags_complex.h>
-
-#include <ags/object/ags_connectable.h>
-#include <ags/object/ags_dynamic_connectable.h>
-#include <ags/object/ags_soundcard.h>
+#include <ags/libags.h>
 
 #include <ags/audio/ags_channel.h>
 #include <ags/audio/ags_recycling.h>
@@ -49,7 +45,6 @@ void ags_envelope_audio_signal_connect_dynamic(AgsDynamicConnectable *dynamic_co
 void ags_envelope_audio_signal_disconnect_dynamic(AgsDynamicConnectable *dynamic_connectable);
 void ags_envelope_audio_signal_finalize(GObject *gobject);
 
-void ags_envelope_audio_signal_run_init_pre(AgsRecall *recall);
 void ags_envelope_audio_signal_run_inter(AgsRecall *recall);
 AgsRecall* ags_envelope_audio_signal_duplicate(AgsRecall *recall,
 					       AgsRecallID *recall_id,
@@ -132,7 +127,6 @@ ags_envelope_audio_signal_class_init(AgsEnvelopeAudioSignalClass *envelope_audio
   /* AgsRecallClass */
   recall = (AgsRecallClass *) envelope_audio_signal;
 
-  recall->run_init_pre = ags_envelope_audio_signal_run_init_pre;
   recall->run_inter = ags_envelope_audio_signal_run_inter;  
   recall->duplicate = ags_envelope_audio_signal_duplicate;
 }
@@ -237,78 +231,14 @@ ags_envelope_audio_signal_duplicate(AgsRecall *recall,
 }
 
 void
-ags_envelope_audio_signal_run_init_pre(AgsRecall *recall)
+ags_envelope_audio_signal_run_inter(AgsRecall *recall)
 {
   AgsEnvelopeChannel *envelope_channel;
   AgsEnvelopeAudioSignal *envelope_audio_signal;
 
   AgsAudioSignal *source;
-  AgsNote *note;
 
-  gdouble delay;
-  gdouble fixed_length;
-  guint buffer_size;
-  gboolean use_note_length, use_fixed_length;
-  
-  GValue value = {0,};
-  
-  /* call parent */
-  AGS_RECALL_CLASS(ags_envelope_audio_signal_parent_class)->run_init_pre(recall);
-
-  /*  */
-  envelope_channel = AGS_ENVELOPE_CHANNEL(AGS_RECALL_CHANNEL_RUN(recall->parent->parent)->recall_channel);
-  envelope_audio_signal = AGS_ENVELOPE_AUDIO_SIGNAL(recall);
-  
-  source = AGS_RECALL_AUDIO_SIGNAL(envelope_audio_signal)->source;
-  note = source->note;
-
-  delay = ags_soundcard_get_delay(AGS_SOUNDCARD(source->soundcard));
-  buffer_size = source->buffer_size;
-
-  /* get use note length port */
-  g_value_init(&value,
-	       G_TYPE_BOOLEAN);
-  ags_port_safe_read(envelope_channel->use_note_length,
-		     &value);
-  
-  use_note_length = g_value_get_boolean(&value);
-  g_value_unset(&value);
-
-  /* get use fixed length port */
-  g_value_init(&value,
-	       G_TYPE_BOOLEAN);
-  ags_port_safe_read(envelope_channel->use_fixed_length,
-		     &value);
-  
-  use_fixed_length = g_value_get_boolean(&value);
-  g_value_unset(&value);
-  
-  /* set frame count */
-  if(use_note_length){
-    envelope_audio_signal->frame_count = (note->x[1] - note->x[0]) * (delay * buffer_size);
-  }else if(use_fixed_length){
-    g_value_init(&value,
-		 G_TYPE_DOUBLE);
-
-    ags_port_safe_read(envelope_channel->fixed_length,
-		       &value);
-
-    fixed_length = g_value_get_double(&value);
-    g_value_unset(&value);
-
-    envelope_audio_signal->frame_count = fixed_length * (delay * buffer_size);
-  }else{
-    envelope_audio_signal->frame_count = AGS_RECALL_AUDIO_SIGNAL(recall)->source->frame_count;
-  }
-}
-
-void
-ags_envelope_audio_signal_run_inter(AgsRecall *recall)
-{
-  AgsEnvelopeAudioSignal *envelope_audio_signal;
-
-  AgsAudioSignal *source;
-  AgsNote *note;
+  GList *note;
   
   AgsComplex *attack;
   AgsComplex *decay;
@@ -318,15 +248,19 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
 
   GList *stream_source;
 
-  gdouble current_volume, current_ratio;
-
   guint frame_count;
   guint buffer_size;
+  gdouble delay;
+  gdouble fixed_length;
+  gdouble current_volume, current_ratio;
 
   guint i, j;
 
+  gboolean use_note_length, use_fixed_length;
+
   GValue audio_value = {0,};
   GValue channel_value = {0,};
+  GValue value = {0,};
 
   auto gdouble ags_envelope_audio_signal_run_inter_get_ratio(guint x0, gdouble y0,
 							     guint x1, gdouble y1);
@@ -355,6 +289,7 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
 
   AGS_RECALL_CLASS(ags_envelope_audio_signal_parent_class)->run_inter(recall);
 
+  envelope_channel = AGS_ENVELOPE_CHANNEL(AGS_RECALL_CHANNEL_RUN(recall->parent->parent)->recall_channel);
   envelope_audio_signal = AGS_ENVELOPE_AUDIO_SIGNAL(recall);
 
   source = AGS_RECALL_AUDIO_SIGNAL(envelope_audio_signal)->source;
@@ -366,183 +301,224 @@ ags_envelope_audio_signal_run_inter(AgsRecall *recall)
     return;
   }
 
+  /* get use note length port */
+  g_value_init(&value,
+	       G_TYPE_BOOLEAN);
+  ags_port_safe_read(envelope_channel->use_note_length,
+		     &value);
+  
+  use_note_length = g_value_get_boolean(&value);
+  g_value_unset(&value);
+
+  /* get use fixed length port */
+  g_value_init(&value,
+	       G_TYPE_BOOLEAN);
+  ags_port_safe_read(envelope_channel->use_fixed_length,
+		     &value);
+  
+  use_fixed_length = g_value_get_boolean(&value);
+  g_value_unset(&value);
+
+  note = source->note;
+
   /* initialize some control values */
-  frame_count = envelope_audio_signal->frame_count;
-
-  if(source->note != NULL &&
-     (AGS_NOTE_ENVELOPE & (AGS_NOTE(source->note)->flags)) != 0){
-    gdouble x0, y0;
-    gdouble x1, y1;
-    guint start_position;
-    guint start_frame, first_frame, buffer_size;
-    guint current_frame, current_buffer_size;
-    guint offset, prev_offset;
+  delay = ags_soundcard_get_delay(AGS_SOUNDCARD(source->soundcard));
+  buffer_size = source->buffer_size;
     
-    note = source->note;
-
-    attack = &(note->attack);
-    decay = &(note->decay);
-    sustain = &(note->sustain);
-    release = &(note->release);
-
-    ratio = &(note->ratio);
-
-    /* get offsets */
-    start_position = g_list_position(source->stream_beginning,
-				     source->stream_current);
-
-    if(start_position == 0){
-      start_frame = 0;
-      first_frame = source->first_frame;
-      buffer_size = source->buffer_size - source->first_frame;
-    }else{
-      start_frame = start_position * source->buffer_size - source->first_frame;
-      first_frame = 0;
-      buffer_size = source->buffer_size;
-    }
-
-    /* attack */
-    x0 = 0.0;
-    y0 = ratio[0][1];
-
-    x1 = attack[0][0];
-    y1 = attack[0][1] + ratio[0][1];
-
-    offset = x1 * frame_count;
-    current_frame = first_frame;
-    
-    if(offset >= start_frame){
-      if(current_frame + x1 * frame_count > buffer_size){
-	current_buffer_size = buffer_size - current_frame;
-      }else{
-	if(x1 * frame_count > buffer_size){
-	  current_buffer_size = buffer_size;
-	}else{
-	  current_buffer_size = x1 * frame_count;
-	}
-      }
+  while(note != NULL){
+    if((AGS_NOTE_ENVELOPE & (AGS_NOTE(note->data)->flags)) != 0){
+      AgsNote *current;
       
-      current_ratio = ags_envelope_audio_signal_run_inter_get_ratio(0, y0,
-								    x1 * frame_count, y1);
-      current_volume = ags_envelope_audio_signal_run_inter_get_volume(y0, current_ratio,
-								      0, start_frame,
-								      x1 * frame_count);
-      ags_audio_buffer_util_envelope(stream_source->data + current_frame, 1,
-				     ags_audio_buffer_util_format_from_soundcard(source->format),
-				     current_buffer_size,
-				     current_volume,
-				     current_ratio);
-
-      current_frame += current_buffer_size;
-    }
-    
-    /* decay */
-    x0 = *attack[0];
-    y0 = *attack[1] + ratio[0][1];
-
-    x1 = *decay[0];
-    y1 = *decay[1] + ratio[0][1];
-
-    prev_offset = offset;
-    offset += (x1 * frame_count);
-
-    if(offset >= start_frame &&
-       prev_offset < start_frame + buffer_size){
-      if(current_frame + x1 * frame_count > buffer_size){
-	current_buffer_size = buffer_size - current_frame;
-      }else{
-	if(x1 * frame_count > buffer_size){
-	  current_buffer_size = buffer_size;
-	}else{
-	  current_buffer_size = x1 * frame_count;
-	}
-      }
+      gdouble x0, y0;
+      gdouble x1, y1;
+      guint start_position;
+      guint start_frame, first_frame, buffer_size;
+      guint current_frame, current_buffer_size;
+      guint offset, prev_offset;
       
-      current_ratio = ags_envelope_audio_signal_run_inter_get_ratio(0, y0,
-								    x1 * frame_count, y1);
-      current_volume = ags_envelope_audio_signal_run_inter_get_volume(y0, current_ratio,
-								      0, prev_offset + current_frame,
-								      x1 * frame_count);
-      ags_audio_buffer_util_envelope(stream_source->data + current_frame, 1,
-				     ags_audio_buffer_util_format_from_soundcard(source->format),
-				     current_buffer_size,
-				     current_volume,
-				     current_ratio);
+      /* set frame count */
+      if(use_note_length){
+	frame_count = (AGS_NOTE(note->data)->x[1] - AGS_NOTE(note->data)->x[0]) * (delay * buffer_size);
+      }else if(use_fixed_length){
+	g_value_init(&value,
+		     G_TYPE_DOUBLE);
 
-      current_frame += current_buffer_size;
-    }
+	ags_port_safe_read(envelope_channel->fixed_length,
+			   &value);
 
-    /* sustain */
-    x0 = *decay[0];
-    y0 = *decay[1] + ratio[0][1];
+	fixed_length = g_value_get_double(&value);
+	g_value_unset(&value);
 
-    x1 = *sustain[0];
-    y1 = *sustain[1] + ratio[0][1];
-
-    prev_offset = offset;
-    offset += (x1 * frame_count);
-
-    if(offset >= start_frame &&
-       prev_offset < start_frame + buffer_size){
-      if(current_frame + x1 * frame_count > buffer_size){
-	current_buffer_size = buffer_size - current_frame;
-      }else{
-	if(x1 * frame_count > buffer_size){
-	  current_buffer_size = buffer_size;
-	}else{
-	  current_buffer_size = x1 * frame_count;
-	}
+	frame_count = fixed_length * (delay * buffer_size);
       }
+
+      current = note->data;
       
-      current_ratio = ags_envelope_audio_signal_run_inter_get_ratio(0, y0,
-								    x1 * frame_count, y1);
-      current_volume = ags_envelope_audio_signal_run_inter_get_volume(y0, current_ratio,
-								      0, prev_offset + current_frame,
-								      x1 * frame_count);
-      ags_audio_buffer_util_envelope(stream_source->data + current_frame, 1,
-				     ags_audio_buffer_util_format_from_soundcard(source->format),
-				     current_buffer_size,
-				     current_volume,
-				     current_ratio);
+      attack = &(current->attack);
+      decay = &(current->decay);
+      sustain = &(current->sustain);
+      release = &(current->release);
 
-      current_frame += current_buffer_size;
-    }
-    
-    /* release */
-    x0 = *sustain[0];
-    y0 = *sustain[1] + ratio[0][1];
+      ratio = &(current->ratio);
 
-    x1 = *release[0];
-    y1 = *release[1] + ratio[0][1];
+      /* get offsets */
+      start_position = floor((delay * current->rt_offset) / frame_count);
 
-    prev_offset = offset;
-    offset += (x1 * frame_count);
-    
-    if(offset >= start_frame &&
-       prev_offset < start_frame + buffer_size){
-      if(current_frame + x1 * frame_count > buffer_size){
-	current_buffer_size = buffer_size - current_frame;
+      if(start_position == 0){
+	start_frame = 0;
+	first_frame = source->first_frame;
+	buffer_size = source->buffer_size - source->first_frame;
       }else{
-	if(x1 * frame_count > buffer_size){
-	  current_buffer_size = buffer_size;
-	}else{
-	  current_buffer_size = x1 * frame_count;
-	}
+	start_frame = start_position * source->buffer_size - source->first_frame;
+	first_frame = 0;
+	buffer_size = source->buffer_size;
       }
-      
-      current_ratio = ags_envelope_audio_signal_run_inter_get_ratio(0, y0,
-								    x1 * frame_count, y1);
-      current_volume = ags_envelope_audio_signal_run_inter_get_volume(y0, current_ratio,
-								      0, prev_offset + current_frame,
-								      x1 * frame_count);
-      ags_audio_buffer_util_envelope(stream_source->data + current_frame, 1,
-				     ags_audio_buffer_util_format_from_soundcard(source->format),
-				     current_buffer_size,
-				     current_volume,
-				     current_ratio);
 
-      current_frame += current_buffer_size;
+      /* attack */
+      x0 = 0.0;
+      y0 = ratio[0][1];
+
+      x1 = attack[0][0];
+      y1 = attack[0][1] + ratio[0][1];
+
+      offset = x1 * frame_count;
+      current_frame = first_frame;
+    
+      if(offset >= start_frame){
+	if(current_frame + x1 * frame_count > buffer_size){
+	  current_buffer_size = buffer_size - current_frame;
+	}else{
+	  if(x1 * frame_count > buffer_size){
+	    current_buffer_size = buffer_size;
+	  }else{
+	    current_buffer_size = x1 * frame_count;
+	  }
+	}
+      
+	current_ratio = ags_envelope_audio_signal_run_inter_get_ratio(0, y0,
+								      x1 * frame_count, y1);
+	current_volume = ags_envelope_audio_signal_run_inter_get_volume(y0, current_ratio,
+									0, start_frame,
+									x1 * frame_count);
+	ags_audio_buffer_util_envelope(stream_source->data + current_frame, 1,
+				       ags_audio_buffer_util_format_from_soundcard(source->format),
+				       current_buffer_size,
+				       current_volume,
+				       current_ratio);
+
+	current_frame += current_buffer_size;
+      }
+    
+      /* decay */
+      x0 = *attack[0];
+      y0 = *attack[1] + ratio[0][1];
+
+      x1 = *decay[0];
+      y1 = *decay[1] + ratio[0][1];
+
+      prev_offset = offset;
+      offset += (x1 * frame_count);
+
+      if(offset >= start_frame &&
+	 prev_offset < start_frame + buffer_size){
+	if(current_frame + x1 * frame_count > buffer_size){
+	  current_buffer_size = buffer_size - current_frame;
+	}else{
+	  if(x1 * frame_count > buffer_size){
+	    current_buffer_size = buffer_size;
+	  }else{
+	    current_buffer_size = x1 * frame_count;
+	  }
+	}
+      
+	current_ratio = ags_envelope_audio_signal_run_inter_get_ratio(0, y0,
+								      x1 * frame_count, y1);
+	current_volume = ags_envelope_audio_signal_run_inter_get_volume(y0, current_ratio,
+									0, prev_offset + current_frame,
+									x1 * frame_count);
+	ags_audio_buffer_util_envelope(stream_source->data + current_frame, 1,
+				       ags_audio_buffer_util_format_from_soundcard(source->format),
+				       current_buffer_size,
+				       current_volume,
+				       current_ratio);
+
+	current_frame += current_buffer_size;
+      }
+
+      /* sustain */
+      x0 = *decay[0];
+      y0 = *decay[1] + ratio[0][1];
+
+      x1 = *sustain[0];
+      y1 = *sustain[1] + ratio[0][1];
+
+      prev_offset = offset;
+      offset += (x1 * frame_count);
+
+      if(offset >= start_frame &&
+	 prev_offset < start_frame + buffer_size){
+	if(current_frame + x1 * frame_count > buffer_size){
+	  current_buffer_size = buffer_size - current_frame;
+	}else{
+	  if(x1 * frame_count > buffer_size){
+	    current_buffer_size = buffer_size;
+	  }else{
+	    current_buffer_size = x1 * frame_count;
+	  }
+	}
+      
+	current_ratio = ags_envelope_audio_signal_run_inter_get_ratio(0, y0,
+								      x1 * frame_count, y1);
+	current_volume = ags_envelope_audio_signal_run_inter_get_volume(y0, current_ratio,
+									0, prev_offset + current_frame,
+									x1 * frame_count);
+	ags_audio_buffer_util_envelope(stream_source->data + current_frame, 1,
+				       ags_audio_buffer_util_format_from_soundcard(source->format),
+				       current_buffer_size,
+				       current_volume,
+				       current_ratio);
+
+	current_frame += current_buffer_size;
+      }
+    
+      /* release */
+      x0 = *sustain[0];
+      y0 = *sustain[1] + ratio[0][1];
+
+      x1 = *release[0];
+      y1 = *release[1] + ratio[0][1];
+
+      prev_offset = offset;
+      offset += (x1 * frame_count);
+    
+      if(offset >= start_frame &&
+	 prev_offset < start_frame + buffer_size){
+	if(current_frame + x1 * frame_count > buffer_size){
+	  current_buffer_size = buffer_size - current_frame;
+	}else{
+	  if(x1 * frame_count > buffer_size){
+	    current_buffer_size = buffer_size;
+	  }else{
+	    current_buffer_size = x1 * frame_count;
+	  }
+	}
+      
+	current_ratio = ags_envelope_audio_signal_run_inter_get_ratio(0, y0,
+								      x1 * frame_count, y1);
+	current_volume = ags_envelope_audio_signal_run_inter_get_volume(y0, current_ratio,
+									0, prev_offset + current_frame,
+									x1 * frame_count);
+	ags_audio_buffer_util_envelope(stream_source->data + current_frame, 1,
+				       ags_audio_buffer_util_format_from_soundcard(source->format),
+				       current_buffer_size,
+				       current_volume,
+				       current_ratio);
+
+	current_frame += current_buffer_size;
+      }
     }
+
+    note = note->next;
   }
 }
 
