@@ -78,7 +78,7 @@ ags_envelope_channel_run_get_type()
     };
 
     ags_type_envelope_channel_run = g_type_register_static(AGS_TYPE_RECALL_CHANNEL_RUN,
-							   "AgsEnvelopeChannelRun\0",
+							   "AgsEnvelopeChannelRun",
 							   &ags_envelope_channel_run_info,
 							   0);
 
@@ -133,10 +133,10 @@ ags_envelope_channel_run_dynamic_connectable_interface_init(AgsDynamicConnectabl
 void
 ags_envelope_channel_run_init(AgsEnvelopeChannelRun *envelope_channel_run)
 {
-  AGS_RECALL(envelope_channel_run)->name = "ags-envelope\0";
+  AGS_RECALL(envelope_channel_run)->name = "ags-envelope";
   AGS_RECALL(envelope_channel_run)->version = AGS_RECALL_DEFAULT_VERSION;
   AGS_RECALL(envelope_channel_run)->build_id = AGS_RECALL_DEFAULT_BUILD_ID;
-  AGS_RECALL(envelope_channel_run)->xml_type = "ags-envelope-channel-run\0";
+  AGS_RECALL(envelope_channel_run)->xml_type = "ags-envelope-channel-run";
   AGS_RECALL(envelope_channel_run)->port = NULL;
 
   AGS_RECALL(envelope_channel_run)->flags |= (AGS_RECALL_OUTPUT_ORIENTATED |
@@ -205,7 +205,7 @@ ags_envelope_channel_run_new(AgsChannel *source)
   AgsEnvelopeChannelRun *envelope_channel_run;
 
   envelope_channel_run = (AgsEnvelopeChannelRun *) g_object_new(AGS_TYPE_ENVELOPE_CHANNEL_RUN,
-								"source\0", source,
+								"source", source,
 								NULL);
 
   return(envelope_channel_run);
