@@ -141,7 +141,7 @@ ags_peak_audio_signal_class_init(AgsPeakAudioSignalClass *peak_audio_signal)
    * 
    * The peak.
    * 
-   * Since: 0.8.2
+   * Since: 1.0.0
    */
   param_spec = g_param_spec_double("peak",
 				   i18n_pspec("resulting peak"),
@@ -295,10 +295,17 @@ ags_peak_audio_signal_run_inter(AgsRecall *recall)
   if(AGS_RECALL_AUDIO_SIGNAL(recall)->source->stream_current != NULL){
     AgsPeakChannel *peak_channel;
 
+    AgsAudioSignal *audio_signal;
+    
     peak_channel = AGS_PEAK_CHANNEL(AGS_RECALL_CHANNEL_RUN(recall->parent->parent)->recall_channel);
 
-    ags_peak_channel_retrieve_peak(peak_channel,
-				   TRUE);
+    audio_signal = AGS_RECALL_AUDIO_SIGNAL(recall)->source;
+    
+    ags_peak_channel_buffer_add(peak_channel,
+				audio_signal->stream_current->data,
+				audio_signal->samplerate,
+				audio_signal->buffer_size,
+				audio_signal->format);
   }else{
     ags_recall_done(recall);
   }
@@ -312,7 +319,7 @@ ags_peak_audio_signal_run_inter(AgsRecall *recall)
  *
  * Returns: a new #AgsPeakAudioSignal
  *
- * Since: 0.4
+ * Since: 1.0.0
  */
 AgsPeakAudioSignal*
 ags_peak_audio_signal_new(AgsAudioSignal *audio_signal)
