@@ -20,20 +20,7 @@
 #include <ags/audio/recall/ags_play_lv2_audio_run.h>
 #include <ags/audio/recall/ags_play_lv2_audio.h>
 
-#include <ags/util/ags_id_generator.h>
-
-#include <ags/object/ags_application_context.h>
-#include <ags/object/ags_config.h>
-#include <ags/object/ags_connectable.h>
-#include <ags/object/ags_dynamic_connectable.h>
-#include <ags/object/ags_plugin.h>
-#include <ags/object/ags_soundcard.h>
-
-#include <ags/thread/ags_mutex_manager.h>
-
-#include <ags/file/ags_file_stock.h>
-#include <ags/file/ags_file_id_ref.h>
-#include <ags/file/ags_file_lookup.h>
+#include <ags/libags.h>
 
 #include <ags/plugin/ags_lv2_manager.h>
 #include <ags/plugin/ags_lv2_plugin.h>
@@ -359,7 +346,7 @@ ags_play_lv2_audio_run_set_property(GObject *gobject,
 	}else{
 	  if((AGS_RECALL_DYNAMIC_CONNECTED & (AGS_RECALL(play_lv2_audio_run)->flags)) != 0){
 	    g_object_disconnect(G_OBJECT(play_lv2_audio_run->delay_audio_run),
-				"notation-alloc-input",
+				"any_signal::notation-alloc-input",
 				G_CALLBACK(ags_play_lv2_audio_run_alloc_input_callback),
 				play_lv2_audio_run,
 				NULL);
@@ -599,7 +586,7 @@ ags_play_lv2_audio_run_disconnect_dynamic(AgsDynamicConnectable *dynamic_connect
 
   if(play_lv2_audio_run->delay_audio_run != NULL){
     g_object_disconnect(G_OBJECT(play_lv2_audio_run->delay_audio_run),
-			"notation-alloc-input",
+			"any_signal::notation-alloc-input",
 			G_CALLBACK(ags_play_lv2_audio_run_alloc_input_callback),
 			play_lv2_audio_run,
 			NULL);
