@@ -23,6 +23,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
+#include <ags/libags.h>
+
 #include <ags/audio/ags_recall_audio_run.h>
 #include <ags/audio/ags_notation.h>
 
@@ -62,7 +64,7 @@ struct _AgsPlayNotationAudioRun
   AgsCountBeatsAudioRun *count_beats_audio_run;
 
   AgsNotation *notation;
-  GList *offset;
+  AgsTimestamp *timestamp;
 };
 
 struct _AgsPlayNotationAudioRunClass
