@@ -23,7 +23,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <ags/thread/ags_task.h>
+#include <ags/libags.h>
+
 #include <ags/audio/ags_recall.h>
 
 #define AGS_TYPE_ADD_RECALL                (ags_add_recall_get_type())
