@@ -22,7 +22,8 @@
 
 #include <glib-object.h>
 
-#include <ags/thread/ags_task.h>
+#include <ags/libags.h>
+
 #include <ags/audio/ags_audio.h>
 
 #define AGS_TYPE_RESIZE_AUDIO                (ags_resize_audio_get_type())
