@@ -23,7 +23,8 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <ags/thread/ags_task.h>
+#include <ags/libags.h>
+
 #include <ags/file/ags_file.h>
 
 #define AGS_TYPE_SAVE_FILE                (ags_save_file_get_type())
