@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2015 Joël Krähemann
+ * Copyright (C) 2005-2017 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -23,7 +23,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <ags/thread/ags_task.h>
+#include <ags/libags.h>
 
 #define AGS_TYPE_SET_SAMPLERATE                (ags_set_samplerate_get_type())
 #define AGS_SET_SAMPLERATE(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_SET_SAMPLERATE, AgsSetSamplerate))
@@ -40,6 +40,7 @@ struct _AgsSetSamplerate
   AgsTask task;
 
   GObject *scope;
+
   guint samplerate;
 };
 
