@@ -23,7 +23,9 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <ags/thread/ags_task.h>
+#include <ags/libags.h>
+
+#include <ags/audio/ags_channel.h>
 #include <ags/audio/ags_pattern.h>
 
 #define AGS_TYPE_TOGGLE_PATTERN_BIT                (ags_toggle_pattern_bit_get_type())
@@ -39,8 +41,10 @@ typedef struct _AgsTogglePatternBitClass AgsTogglePatternBitClass;
 struct _AgsTogglePatternBit
 {
   AgsTask task;
-  
+
+  AgsChannel *channel;
   AgsPattern *pattern;
+  
   guint line;
 
   guint index_i;
