@@ -37,13 +37,13 @@ typedef struct _AgsConnectableInterface AgsConnectableInterface;
 
 struct _AgsConnectableInterface
 {
-  GTypeInterface interface;
+  GTypeInterface ginterface;
 
   void (*add_to_registry)(AgsConnectable *connectable);
   void (*remove_from_registry)(AgsConnectable *connectable);
 
   xmlNode* (*update)(AgsConnectable *connectable);
-
+  
   gboolean (*is_ready)(AgsConnectable *connectable);
   gboolean (*is_connected)(AgsConnectable *connectable);
 
