@@ -42,6 +42,7 @@ void ags_lv2ui_plugin_get_property(GObject *gobject,
 				   guint prop_id,
 				   GValue *value,
 				   GParamSpec *param_spec);
+void ags_lv2ui_plugin_dispose(GObject *gobject);
 void ags_lv2ui_plugin_finalize(GObject *gobject);
 
 gpointer ags_lv2ui_plugin_instantiate(AgsBasePlugin *base_plugin,
@@ -100,7 +101,7 @@ ags_lv2ui_plugin_get_type (void)
     };
 
     ags_type_lv2ui_plugin = g_type_register_static(AGS_TYPE_BASE_PLUGIN,
-						   "AgsLv2uiPlugin\0",
+						   "AgsLv2uiPlugin",
 						   &ags_lv2ui_plugin_info,
 						   0);
   }
@@ -124,6 +125,7 @@ ags_lv2ui_plugin_class_init(AgsLv2uiPluginClass *lv2ui_plugin)
   gobject->set_property = ags_lv2ui_plugin_set_property;
   gobject->get_property = ags_lv2ui_plugin_get_property;
 
+  gobject->dispose = ags_lv2ui_plugin_dispose;
   gobject->finalize = ags_lv2ui_plugin_finalize;
 
   /* properties */
@@ -132,11 +134,11 @@ ags_lv2ui_plugin_class_init(AgsLv2uiPluginClass *lv2ui_plugin)
    *
    * The assigned GUI URI.
    * 
-   * Since: 0.7.127
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_string("gui-uri\0",
-				   "GUI URI of the plugin\0",
-				   "The GUI URI this plugin is located in\0",
+  param_spec = g_param_spec_string("gui-uri",
+				   "GUI URI of the plugin",
+				   "The GUI URI this plugin is located in",
 				   NULL,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -148,11 +150,11 @@ ags_lv2ui_plugin_class_init(AgsLv2uiPluginClass *lv2ui_plugin)
    *
    * The assigned manifest.
    * 
-   * Since: 0.7.6
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_object("manifest\0",
-				   "manifest of the plugin\0",
-				   "The manifest this plugin is located in\0",
+  param_spec = g_param_spec_object("manifest",
+				   "manifest of the plugin",
+				   "The manifest this plugin is located in",
 				   AGS_TYPE_TURTLE,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -164,11 +166,11 @@ ags_lv2ui_plugin_class_init(AgsLv2uiPluginClass *lv2ui_plugin)
    *
    * The assigned GUI turtle.
    * 
-   * Since: 0.7.127
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_object("gui-turtle\0",
-				   "GUI turtle of the plugin\0",
-				   "The GUI turtle this plugin is located in\0",
+  param_spec = g_param_spec_object("gui-turtle",
+				   "GUI turtle of the plugin",
+				   "The GUI turtle this plugin is located in",
 				   AGS_TYPE_TURTLE,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -180,11 +182,11 @@ ags_lv2ui_plugin_class_init(AgsLv2uiPluginClass *lv2ui_plugin)
    *
    * The assigned LV2 plugin.
    * 
-   * Since: 0.7.127
+   * Since: 1.0.0
    */
-  param_spec = g_param_spec_object("lv2-plugin\0",
-				   "LV2 plugin of the plugin\0",
-				   "The LV2 plugin this plugin is located in\0",
+  param_spec = g_param_spec_object("lv2-plugin",
+				   "LV2 plugin of the plugin",
+				   "The LV2 plugin this plugin is located in",
 				   AGS_TYPE_LV2_PLUGIN,
 				   G_PARAM_READABLE | G_PARAM_WRITABLE);
   g_object_class_install_property(gobject,
@@ -344,6 +346,35 @@ ags_lv2ui_plugin_get_property(GObject *gobject,
   }
 }
 
+void
+ags_lv2ui_plugin_dispose(GObject *gobject)
+{
+  AgsLv2uiPlugin *lv2ui_plugin;
+
+  lv2ui_plugin = AGS_LV2UI_PLUGIN(gobject);
+
+  if(lv2ui_plugin->manifest != NULL){
+    g_object_unref(lv2ui_plugin->manifest);
+
+    lv2ui_plugin->manifest = NULL;
+  }
+
+  if(lv2ui_plugin->gui_turtle != NULL){
+    g_object_unref(lv2ui_plugin->gui_turtle);
+
+    lv2ui_plugin->gui_turtle = NULL;
+  }
+
+  if(lv2ui_plugin->lv2_plugin != NULL){
+    g_object_unref(lv2ui_plugin->lv2_plugin);
+
+    lv2ui_plugin->lv2_plugin = NULL;
+  }
+
+  /* call parent */
+  G_OBJECT_CLASS(ags_lv2ui_plugin_parent_class)->dispose(gobject);
+}
+
 void
 ags_lv2ui_plugin_finalize(GObject *gobject)
 {
@@ -364,6 +395,9 @@ ags_lv2ui_plugin_finalize(GObject *gobject)
   if(lv2ui_plugin->lv2_plugin != NULL){
     g_object_unref(lv2ui_plugin->lv2_plugin);
   }
+
+  /* call parent */
+  G_OBJECT_CLASS(ags_lv2ui_plugin_parent_class)->finalize(gobject);
 }
 
 void
@@ -381,7 +415,7 @@ ags_lv2ui_plugin_load_plugin(AgsBasePlugin *base_plugin)
  * 
  * Returns: the next matching #GList-struct
  * 
- * Since: 0.7.127
+ * Since: 1.0.0
  */
 GList*
 ags_lv2ui_plugin_find_gui_uri(GList *lv2ui_plugin,
@@ -416,7 +450,7 @@ ags_lv2ui_plugin_find_gui_uri(GList *lv2ui_plugin,
  *
  * Returns: a new #AgsLv2uiPlugin
  *
- * Since: 0.7.6
+ * Since: 1.0.0
  */
 AgsLv2uiPlugin*
 ags_lv2ui_plugin_new(AgsTurtle *gui_turtle, gchar *filename, gchar *effect, gchar *gui_uri, guint effect_index)
@@ -424,11 +458,11 @@ ags_lv2ui_plugin_new(AgsTurtle *gui_turtle, gchar *filename, gchar *effect, gcha
   AgsLv2uiPlugin *lv2ui_plugin;
 
   lv2ui_plugin = (AgsLv2uiPlugin *) g_object_new(AGS_TYPE_LV2UI_PLUGIN,
-						 "gui-turtle\0", gui_turtle,
-						 "filename\0", filename,
-						 "effect\0", effect,
-						 "gui-uri\0", gui_uri,
-						 "effect-index\0", effect_index,
+						 "gui-turtle", gui_turtle,
+						 "filename", filename,
+						 "effect", effect,
+						 "gui-uri", gui_uri,
+						 "effect-index", effect_index,
 						 NULL);
 
   return(lv2ui_plugin);
