@@ -116,6 +116,8 @@ ags_functional_line_member_add_and_destroy_test_add_test()
   CU_basic_set_mode(CU_BRM_VERBOSE);
   CU_basic_run_tests();
   
+  ags_test_quit();
+  
   CU_cleanup_registry();
   
   exit(CU_get_error());
@@ -1380,6 +1382,8 @@ main(int argc, char **argv)
   ags_functional_test_util_do_run(argc, argv,
 				  ags_functional_line_member_add_and_destroy_test_add_test, &is_available);
 
+  pthread_join(ags_functional_test_util_self(),
+	       NULL);
+
   return(-1);
 }
-
