@@ -39,6 +39,7 @@
 #include <ags/X/thread/ags_gui_thread.h>
 
 #include "gsequencer_setup_util.h"
+#include "ags_functional_test_util.h"
 
 void ags_functional_notation_edit_test_add_test();
 
@@ -100,6 +101,8 @@ ags_functional_notation_edit_test_add_test()
   CU_basic_set_mode(CU_BRM_VERBOSE);
   CU_basic_run_tests();
   
+  ags_test_quit();
+
   CU_cleanup_registry();
   
   exit(CU_get_error());
@@ -232,6 +235,8 @@ main(int argc, char **argv)
   ags_functional_test_util_do_run(argc, new_argv,
 				  ags_functional_notation_edit_test_add_test, &is_available);
 
+  pthread_join(ags_functional_test_util_self(),
+	       NULL);
+
   return(-1);
 }
-
