@@ -99,6 +99,8 @@ ags_functional_matrix_test_add_test()
   /* Run all tests using the CUnit Basic interface */
   CU_basic_set_mode(CU_BRM_VERBOSE);
   CU_basic_run_tests();
+
+  ags_test_quit();
   
   CU_cleanup_registry();
   
@@ -315,5 +317,8 @@ main(int argc, char **argv)
   ags_functional_test_util_do_run(argc, argv,
 				  ags_functional_matrix_test_add_test, &is_available);
 
+  pthread_join(ags_functional_test_util_self(),
+	       NULL);
+
   return(-1);
 }
