@@ -140,27 +140,29 @@ ags_notation_test_find_near_timestamp()
     /* nth notation */
     notation[i] = ags_notation_new(audio,
 				   0);
-    timestamp = ags_timestamp_new();
-    g_object_set(notation[i],
-		 "timestamp\0", timestamp,
-		 NULL);
+    timestamp = notation[i]->timestamp;
 
-    timestamp->timer.unix_time.time_val = AGS_TIMESTAMP(notation[0]->timestamp)->timer.unix_time.time_val + ((i + 1) * AGS_NOTATION_DEFAULT_DURATION);
+    timestamp->timer.ags_offset.offset = i * AGS_NOTATION_DEFAULT_OFFSET;
 
     list = g_list_prepend(list,
 			  notation[i]);
   }
 
+  list = g_list_reverse(list);
+
   /* instantiate timestamp to check against */
   timestamp = ags_timestamp_new();
-  
+
+  timestamp->flags &= (~AGS_TIMESTAMP_UNIX);
+  timestamp->flags |= AGS_TIMESTAMP_OFFSET;
+
   /* assert find */
-  for(i = 0; i + 1 < AGS_NOTATION_TEST_FIND_NEAR_TIMESTAMP_N_NOTATION; i++){
-    timestamp->timer.unix_time.time_val = AGS_TIMESTAMP(notation[0]->timestamp)->timer.unix_time.time_val + ((i + 1) * AGS_NOTATION_DEFAULT_DURATION + 1);
+  for(i = 0; i < AGS_NOTATION_TEST_FIND_NEAR_TIMESTAMP_N_NOTATION; i++){
+    timestamp->timer.ags_offset.offset = i * AGS_NOTATION_DEFAULT_OFFSET;
     current = ags_notation_find_near_timestamp(list, 0,
 					       timestamp);
 
-    CU_ASSERT(current != NULL && current->data == notation[i + 1]);
+    CU_ASSERT(current != NULL && current->data == notation[i]);
   }  
 }
 
