@@ -38,6 +38,9 @@
 #define AGS_IS_THREAD_POOL_CLASS(class)     (G_TYPE_CHECK_CLASS_TYPE ((class), AGS_TYPE_THREAD_POOL))
 #define AGS_THREAD_POOL_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS(obj, AGS_TYPE_THREAD_POOL, AgsThreadPoolClass))
 
+#define AGS_THREAD_POOL_DEFAULT_MAX_UNUSED_THREADS 4
+#define AGS_THREAD_POOL_DEFAULT_MAX_THREADS 1024
+
 #ifndef AGS_THREAD_POOL_RT_PRIORITY
 #define AGS_THREAD_POOL_RT_PRIORITY (99)
 #endif
